@@ -1,5 +1,5 @@
 /*
-   ARPACK++ v1.0 8/1/1997
+   ARPACK++ v1.2 2/20/2000
    c++ interface to ARPACK code.
 
    MODULE MatProd.h
@@ -20,7 +20,7 @@
 #ifndef MATPROD_H
 #define MATPROD_H
 
-template<class T>
+template<class ART>
 class MatrixWithProduct {
 
  private:
@@ -33,7 +33,7 @@ class MatrixWithProduct {
 
   int ncols() { return n; }
 
-  virtual void MultMv(T* v, T* w) = 0;
+  virtual void MultMv(ART* v, ART* w) = 0;
   // Matrix-vector product: w = M*v.
 
   MatrixWithProduct(int nrows, int ncols = 0)
