@@ -1,5 +1,5 @@
 /*
-   ARPACK++ v1.0 8/1/1997
+   ARPACK++ v1.2 2/20/2000
    c++ interface to ARPACK code.
 
    MODULE SMatrixC.h
@@ -22,22 +22,22 @@
 #include "blas1c.h"
 #include "lapackc.h"
 
-template<class T>
-class SymMatrixC: public MatrixWithProduct<T> {
+template<class ART>
+class SymMatrixC: public MatrixWithProduct<ART> {
 
  public:
 
-  void MultMv(T* v, T* w);
+  void MultMv(ART* v, ART* w);
 
-  SymMatrixC(int nv): MatrixWithProduct<T>(nv) { }
+  SymMatrixC(int nv): MatrixWithProduct<ART>(nv) { }
 
   virtual ~SymMatrixC() { }
 
 }; // SymMatrixC.
 
 
-template<class T>
-void SymMatrixC<T>::MultMv(T* v, T* w)
+template<class ART>
+void SymMatrixC<ART>::MultMv(ART* v, ART* w)
 /*
   Matrix-vector product.
 */
@@ -45,20 +45,20 @@ void SymMatrixC<T>::MultMv(T* v, T* w)
 {
 
   int  j;
-  T    h2;
+  ART  h2;
 
-  const T two = 2.0;
+  const ART two = 2.0;
 
   w[0] =  two*v[0] - v[1];
-  for (j=1; j<ncols()-1; j++) {
+  for (j=1; j<this->ncols()-1; j++) {
     w[j] = - v[j-1] + two*v[j] - v[j+1];
   }
-  w[ncols()-1] = - v[ncols()-2] + two*v[ncols()-1];
+  w[this->ncols()-1] = - v[this->ncols()-2] + two*v[this->ncols()-1];
 
   // Scaling the vector w by (1 / h).
 
-  h2 = T(ncols()+1);
-  scal(ncols(), h2, w, 1L);
+  h2 = ART(this->ncols()+1);
+  scal(this->ncols(), h2, w, 1L);
 
   return;
 
