@@ -1,5 +1,5 @@
 /*
-   ARPACK++ v1.0 8/1/1997
+   ARPACK++ v1.2 2/20/2000
    c++ interface to ARPACK code.
 
    MODULE BCMatrxB.h
@@ -22,21 +22,21 @@
 
 #include "arcomp.h"
 
-template<class FLOAT, class INT>
-void CompMatrixB(INT n, arcomplex<FLOAT> rho, INT& nL, 
-                 INT& nU, arcomplex<FLOAT>* &A)
+template<class ARFLOAT, class ARINT>
+void CompMatrixB(ARINT n, arcomplex<ARFLOAT> rho, ARINT& nL, 
+                 ARINT& nU, arcomplex<ARFLOAT>* &A)
 {
 
-  INT              i;
-  arcomplex<FLOAT> dd, dl, du, h;
+  ARINT              i;
+  arcomplex<ARFLOAT> dd, dl, du, h;
 
   // Defining constants.
 
-  const arcomplex<FLOAT> one( 1.0, 0.0);
-  const arcomplex<FLOAT> two( 2.0, 0.0);
-  const arcomplex<FLOAT> half( 0.5, 0.0);
+  const arcomplex<ARFLOAT> one( 1.0, 0.0);
+  const arcomplex<ARFLOAT> two( 2.0, 0.0);
+  const arcomplex<ARFLOAT> half( 0.5, 0.0);
 
-  h  = one/arcomplex<FLOAT>((FLOAT)(n+1),0.0);
+  h  = one/arcomplex<ARFLOAT>((ARFLOAT)(n+1),0.0);
   dd = two/h;
   dl = -(one/h) - half*rho;
   du = -(one/h) + half*rho;
@@ -48,7 +48,7 @@ void CompMatrixB(INT n, arcomplex<FLOAT> rho, INT& nL,
 
   // Creating output vector A.
 
-  A  = new arcomplex<FLOAT>[3*n];
+  A  = new arcomplex<ARFLOAT>[3*n];
   for (i=1; i<(3*n); i+=3) {
     if (i-1)   A[i-1] = du;
                A[i]   = dd;
