@@ -1,5 +1,5 @@
 /*
-   ARPACK++ v1.0 8/1/1997
+   ARPACK++ v1.2 2/20/2000
    c++ interface to ARPACK code.
 
    MODULE LCMatrxE.h
@@ -20,20 +20,20 @@
 
 #include "arcomp.h"
 
-template<class FLOAT, class INT>
-void CompMatrixE(INT n, arcomplex<FLOAT> rho, INT& nnz, 
-                 arcomplex<FLOAT>* &A, INT* &irow, INT* &pcol)
+template<class ARFLOAT, class ARINT>
+void CompMatrixE(ARINT n, arcomplex<ARFLOAT> rho, ARINT& nnz, 
+                 arcomplex<ARFLOAT>* &A, ARINT* &irow, ARINT* &pcol)
 {
 
-  INT              i, j;
-  arcomplex<FLOAT> dd, dl, du, s, h;
+  ARINT              i, j;
+  arcomplex<ARFLOAT> dd, dl, du, s, h;
 
   // Defining constants.
 
-  const arcomplex<FLOAT> one( 1.0, 0.0);
-  const arcomplex<FLOAT> two( 2.0, 0.0);
+  const arcomplex<ARFLOAT> one( 1.0, 0.0);
+  const arcomplex<ARFLOAT> two( 2.0, 0.0);
 
-  h  = one/arcomplex<FLOAT>((FLOAT)(n+1),0.0);
+  h  = one/arcomplex<ARFLOAT>((ARFLOAT)(n+1),0.0);
   s  = rho/two;
   dd = two/h;
   dl = -(one/h) - s;
@@ -45,9 +45,9 @@ void CompMatrixE(INT n, arcomplex<FLOAT> rho, INT& nnz,
 
   // Creating output vectors.
 
-  A    = new arcomplex<FLOAT>[nnz];
-  irow = new INT[nnz];
-  pcol = new INT[n+1];
+  A    = new arcomplex<ARFLOAT>[nnz];
+  irow = new ARINT[nnz];
+  pcol = new ARINT[n+1];
 
   // Filling A, irow and pcol.
 
