@@ -1,5 +1,5 @@
 /*
-   ARPACK++ v1.0 8/1/1997
+   ARPACK++ v1.2 2/20/2000
    c++ interface to ARPACK code.
 
    MODULE LCMatrxF.h
@@ -19,20 +19,20 @@
 
 #include "arcomp.h"
 
-template<class FLOAT, class INT>
-void CompMatrixF(INT n, INT& nnz, arcomplex<FLOAT>* &A, 
-                 INT* &irow, INT* &pcol)
+template<class ARFLOAT, class ARINT>
+void CompMatrixF(ARINT n, ARINT& nnz, arcomplex<ARFLOAT>* &A, 
+                 ARINT* &irow, ARINT* &pcol)
 {
 
-  INT              i, j;
-  arcomplex<FLOAT> h, dd, ds;
+  ARINT              i, j;
+  arcomplex<ARFLOAT> h, dd, ds;
 
   // Defining constants.
 
-  const arcomplex<FLOAT> one(1.0, 0.0);
-  const arcomplex<FLOAT> four(4.0, 0.0);
+  const arcomplex<ARFLOAT> one(1.0, 0.0);
+  const arcomplex<ARFLOAT> four(4.0, 0.0);
 
-  h  = one/arcomplex<FLOAT>((FLOAT)(n+1),0.0);
+  h  = one/arcomplex<ARFLOAT>((ARFLOAT)(n+1),0.0);
   dd = four*h;
   ds = one*h;
 
@@ -42,9 +42,9 @@ void CompMatrixF(INT n, INT& nnz, arcomplex<FLOAT>* &A,
 
   // Creating output vectors.
 
-  A    = new arcomplex<FLOAT>[nnz];
-  irow = new INT[nnz];
-  pcol = new INT[n+1];
+  A    = new arcomplex<ARFLOAT>[nnz];
+  irow = new ARINT[nnz];
+  pcol = new ARINT[n+1];
 
   // Filling A, irow and pcol.
 
