@@ -1,5 +1,5 @@
 /*
-   ARPACK++ v1.0 8/1/1997
+   ARPACK++ v1.2 2/20/2000
    c++ interface to ARPACK code.
 
    MODULE BNMatrxC.h
@@ -18,17 +18,17 @@
 #ifndef BNMATRXC_H
 #define BNMATRXC_H
 
-template<class FLOAT, class INT>
-void MassMatrix(INT n, INT& nL, INT& nU, FLOAT* &A)
+template<class ARFLOAT, class ARINT>
+void MassMatrix(ARINT n, ARINT& nL, ARINT& nU, ARFLOAT* &A)
 {
 
-  INT   i;
-  FLOAT diag, sub;
+  ARINT   i;
+  ARFLOAT diag, sub;
 
   // Defining constants.
 
-  sub  = 1.0/FLOAT(n+1);
-  diag = 4.0/FLOAT(n+1);
+  sub  = 1.0/6.0/ARFLOAT(n+1);
+  diag = 4.0/6.0/ARFLOAT(n+1);
 
   // Defining the lower and upper bandwidth.
 
@@ -37,7 +37,7 @@ void MassMatrix(INT n, INT& nL, INT& nU, FLOAT* &A)
 
   // Creating output vector A.
 
-  A  = new FLOAT[3*n];
+  A  = new ARFLOAT[3*n];
   for (i=1; i<(3*n); i+=3) {
     if (i-1)   A[i-1] = sub;
                A[i]   = diag;
