@@ -1,5 +1,5 @@
 /*
-   ARPACK++ v1.0 8/1/1997
+   ARPACK++ v1.2 2/20/2000
    c++ interface to ARPACK code.
 
    MODULE BNMatrxD.h
@@ -20,17 +20,18 @@
 #ifndef BNMATRXD_H
 #define BNMATRXD_H
 
-template<class FLOAT, class INT>
-void BandMatrixD(INT nx, FLOAT rho, INT& n, INT& nL, INT& nU, FLOAT* &A)
+template<class ARFLOAT, class ARINT>
+void BandMatrixD(ARINT nx, ARFLOAT rho, ARINT& n, ARINT& nL, ARINT& nU, 
+                 ARFLOAT* &A)
 
 {
 
-  INT   i, j, lda;
-  FLOAT dd, dl, du, h;
+  ARINT   i, j, lda;
+  ARFLOAT dd, dl, du, h;
 
   // Defining constants.
 
-  h  = 1.0/FLOAT(nx+1);
+  h  = 1.0/ARFLOAT(nx+1);
   dd = 4.0;
   dl = -1.0 - 0.5*rho*h;
   du = -1.0 + 0.5*rho*h;
@@ -44,11 +45,11 @@ void BandMatrixD(INT nx, FLOAT rho, INT& n, INT& nL, INT& nU, FLOAT* &A)
   // Creating output vector A.
 
   lda = nL+nU+1;
-  A   = new FLOAT[n*lda];
+  A   = new ARFLOAT[n*lda];
 
   // Filling A with zeros.
 
-  for (j=0; j<(n*lda); j++ ) A[j] = (FLOAT)0.0;
+  for (j=0; j<(n*lda); j++ ) A[j] = (ARFLOAT)0.0;
 
   // Creating matrix A.
 
