@@ -1,5 +1,5 @@
 /*
-   ARPACK++ v1.0 8/1/1997
+   ARPACK++ v1.2 2/20/2000
    c++ interface to ARPACK code.
 
    MODULE BNMatrxE.h
@@ -18,12 +18,12 @@
 #ifndef BNMATRXE_H
 #define BNMATRXE_H
 
-template<class FLOAT, class INT>
-void BandMatrixE(INT n, INT& nL, INT& nU, FLOAT* &A)
+template<class ARFLOAT, class ARINT>
+void BandMatrixE(ARINT n, ARINT& nL, ARINT& nU, ARFLOAT* &A)
 
 {
 
-  INT   j;
+  ARINT j;
 
   // Defining the upper and lower bandwidth.
 
@@ -32,7 +32,7 @@ void BandMatrixE(INT n, INT& nL, INT& nU, FLOAT* &A)
 
   // Creating output vector A.
 
-  A   = new FLOAT[3*n];
+  A   = new ARFLOAT[3*n];
   for (j=1; j<(3*n); j+=3) {
     if (j-1)    A[j-1] = 1.0;
                 A[j]   = 4.0;
