@@ -1,5 +1,5 @@
 /*
-   ARPACK++ v1.0 8/1/1997
+   ARPACK++ v1.2 2/20/2000
    c++ interface to ARPACK code.
 
    MODULE BNMatrxW.h
@@ -23,20 +23,20 @@
 #define BNMATRXW_H
 
 
-template<class FLOAT>
-void MatrixW(int n, int nl, int nu, FLOAT* &A)
+template<class ARFLOAT>
+void MatrixW(int n, int nl, int nu, ARFLOAT* &A)
 {
 
-  int   i, j, p;
-  FLOAT h;
+  int     i, j, p;
+  ARFLOAT h;
 
   // Defining h.
 
-  h = 1.0/FLOAT(n+1);
+  h = 1.0/ARFLOAT(n+1);
 
   // Creating output vector A.
 
-  A = new FLOAT[n*(nl+nu+1)];
+  A = new ARFLOAT[n*(nl+nu+1)];
 
   p = 0;
 
@@ -47,7 +47,7 @@ void MatrixW(int n, int nl, int nu, FLOAT* &A)
         A[p++] = 0.0;
       }
       else {
-        A[p++] = h*(FLOAT(j)*h-1.0)*(FLOAT(i)*h);
+        A[p++] = h*(ARFLOAT(j)*h-1.0)*(ARFLOAT(i)*h);
       }
     }
 
@@ -56,7 +56,7 @@ void MatrixW(int n, int nl, int nu, FLOAT* &A)
         A[p++] = 0.0;
       }
       else {
-        A[p++]  = h*(FLOAT(i)*h-1.0)*(FLOAT(j)*h);
+        A[p++]  = h*(ARFLOAT(i)*h-1.0)*(ARFLOAT(j)*h);
       }
     }
 
