@@ -1,5 +1,5 @@
 /*
-   ARPACK++ v1.0 8/1/1997
+   ARPACK++ v1.2 2/20/2000
    c++ interface to ARPACK code.
 
    MODULE DNMatrxB.h
@@ -21,23 +21,23 @@
 #ifndef DNMATRXB_H
 #define DNMATRXB_H
 
-template<class FLOAT, class INT>
-void StiffnessMatrix(INT n, FLOAT rho, FLOAT* &A)
+template<class ARFLOAT, class ARINT>
+void StiffnessMatrix(ARINT n, ARFLOAT rho, ARFLOAT* &A)
 {
 
-  INT   i, j;
-  FLOAT dd, dl, du, h;
+  ARINT   i, j;
+  ARFLOAT dd, dl, du, h;
 
   // Defining constants.
 
-  h  = 1.0/FLOAT(n+1);
+  h  = 1.0/ARFLOAT(n+1);
   dd = 2.0/h;
   dl = -1.0/h - 0.5*rho;
   du = -1.0/h + 0.5*rho;
 
   // Creating output vector A.
 
-  A  = new FLOAT[n*n];
+  A  = new ARFLOAT[n*n];
 
   for (i=0; i<n*n; i++) A[i]=0.0;
 
