@@ -1,5 +1,5 @@
 /*
-   ARPACK++ v1.0 8/1/1997
+   ARPACK++ v1.2 2/20/2000
    c++ interface to ARPACK code.
 
    MODULE DNMatrxC.h
@@ -18,21 +18,21 @@
 #ifndef DNMATRXC_H
 #define DNMATRXC_H
 
-template<class FLOAT, class INT>
-void MassMatrix(INT n, FLOAT* &A)
+template<class ARFLOAT, class ARINT>
+void MassMatrix(ARINT n, ARFLOAT* &A)
 {
 
-  INT   i, j;
-  FLOAT diag, sub;
+  ARINT   i, j;
+  ARFLOAT diag, sub;
 
   // Defining constants.
 
-  sub  = 1.0/FLOAT(n+1);
-  diag = 4.0/FLOAT(n+1);
+  sub  = 1.0/6.0/ARFLOAT(n+1);
+  diag = 4.0/6.0/ARFLOAT(n+1);
 
   // Creating output vector A.
 
-  A  = new FLOAT[n*n];
+  A  = new ARFLOAT[n*n];
 
   for (i=0; i<n*n; i++) A[i]=0.0;
 
