@@ -1,5 +1,5 @@
 /*
-   ARPACK++ v1.0 8/1/1997
+   ARPACK++ v1.2 2/20/2000
    c++ interface to ARPACK code.
 
    MODULE DNMatrxD.h
@@ -20,17 +20,17 @@
 #ifndef DNMATRXD_H
 #define DNMATRXD_H
 
-template<class FLOAT, class INT>
-void DenseMatrixD(INT nx, FLOAT rho, INT& n, FLOAT* &A)
+template<class ARFLOAT, class ARINT>
+void DenseMatrixD(ARINT nx, ARFLOAT rho, ARINT& n, ARFLOAT* &A)
 
 {
 
-  INT   i, j;
-  FLOAT dd, dl, du, h;
+  ARINT   i, j;
+  ARFLOAT dd, dl, du, h;
 
   // Defining constants.
 
-  h  = 1.0/FLOAT(nx+1);
+  h  = 1.0/ARFLOAT(nx+1);
   dd = 4.0;
   dl = -1.0 - 0.5*rho*h;
   du = -1.0 + 0.5*rho*h;
@@ -41,7 +41,7 @@ void DenseMatrixD(INT nx, FLOAT rho, INT& n, FLOAT* &A)
 
   // Creating output vector A.
 
-  A  = new FLOAT[n*n];
+  A  = new ARFLOAT[n*n];
 
   for (i=0; i<n*n; i++) A[i]=0.0;
 
