@@ -1,5 +1,5 @@
 /*
-   ARPACK++ v1.0 8/1/1997
+   ARPACK++ v1.2 2/20/2000
    c++ interface to ARPACK code.
 
    MODULE DNMatrxE.h
@@ -18,16 +18,16 @@
 #ifndef DNMATRXE_H
 #define DNMATRXE_H
 
-template<class FLOAT, class INT>
-void DenseMatrixE(INT n, FLOAT* &A)
+template<class ARFLOAT, class ARINT>
+void DenseMatrixE(ARINT n, ARFLOAT* &A)
 
 {
 
-  INT i, j;
+  ARINT i, j;
 
   // Creating output vector A.
 
-  A  = new FLOAT[n*n];
+  A  = new ARFLOAT[n*n];
 
   for (i=0; i<n*n; i++) A[i]=0.0;
 
