@@ -1,5 +1,5 @@
 /*
-   ARPACK++ v1.0 8/1/1997
+   ARPACK++ v1.2 2/20/2000
    c++ interface to ARPACK code.
 
    MODULE DNMatrxW.h
@@ -23,30 +23,30 @@
 #define DNMATRXW_H
 
 
-template<class FLOAT>
-void MatrixW(int m, int n, FLOAT* &A)
+template<class ARFLOAT>
+void MatrixW(int m, int n, ARFLOAT* &A)
 {
 
   int   i, j, p;
-  FLOAT h, k;
+  ARFLOAT h, k;
 
   // Defining h.
 
-  h = 1.0/FLOAT(m+1);
-  k = 1.0/FLOAT(n+1);
+  h = 1.0/ARFLOAT(m+1);
+  k = 1.0/ARFLOAT(n+1);
 
   // Creating output vector A.
 
-  A = new FLOAT[m*n];
+  A = new ARFLOAT[m*n];
 
   p = 0;
   for (j=1; j<=n; j++) {
 
     for (i=1; i<=j; i++) {
-      A[p++] = k*(FLOAT(j)*k-1.0)*(FLOAT(i)*h);
+      A[p++] = k*(ARFLOAT(j)*k-1.0)*(ARFLOAT(i)*h);
     }
     for(i=j+1; i<=m; i++) {
-      A[p++]  = k*(FLOAT(i)*h-1.0)*(FLOAT(j)*k);
+      A[p++]  = k*(ARFLOAT(i)*h-1.0)*(ARFLOAT(j)*k);
     }
 
   }
