@@ -1,5 +1,5 @@
 /*
-   ARPACK++ v1.0 8/1/1997
+   ARPACK++ v1.2 2/20/2000
    c++ interface to ARPACK code.
 
    MODULE LNMatrxC.h
@@ -21,20 +21,20 @@
 #ifndef LNMATRXC_H
 #define LNMATRXC_H
 
-template<class FLOAT, class INT>
-void StiffnessMatrix(INT n, FLOAT rho, INT& nnz,
-                     FLOAT* &A, INT* &irow, INT* &pcol)
+template<class ARFLOAT, class ARINT>
+void StiffnessMatrix(ARINT n, ARFLOAT rho, ARINT& nnz,
+                     ARFLOAT* &A, ARINT* &irow, ARINT* &pcol)
 {
 
-  INT   i, j;
-  FLOAT dd, dl, du, s, h;
+  ARINT   i, j;
+  ARFLOAT dd, dl, du, s, h;
 
   // Defining constants.
 
-  const FLOAT one = 1.0;
-  const FLOAT two = 2.0;
+  const ARFLOAT one = 1.0;
+  const ARFLOAT two = 2.0;
 
-  h  = one/FLOAT(n+1);
+  h  = one/ARFLOAT(n+1);
   s  = rho/two;
   dd = two/h;
   dl = -one/h - s;
@@ -46,9 +46,9 @@ void StiffnessMatrix(INT n, FLOAT rho, INT& nnz,
 
   // Creating output vectors.
 
-  A    = new FLOAT[nnz];
-  irow = new INT[nnz];
-  pcol = new INT[n+1];
+  A    = new ARFLOAT[nnz];
+  irow = new ARINT[nnz];
+  pcol = new ARINT[n+1];
 
   // Filling A, irow and pcol.
 
