@@ -1,5 +1,5 @@
 /*
-   ARPACK++ v1.0 8/1/1997
+   ARPACK++ v1.2 2/20/2000
    c++ interface to ARPACK code.
 
    MODULE LNMatrxD.h
@@ -18,17 +18,17 @@
 #ifndef LNMATRXD_H
 #define LNMATRXD_H
 
-template<class FLOAT, class INT>
-void MassMatrix(INT n, INT& nnz, FLOAT* &A, INT* &irow, INT* &pcol)
+template<class ARFLOAT, class ARINT>
+void MassMatrix(ARINT n, ARINT& nnz, ARFLOAT* &A, ARINT* &irow, ARINT* &pcol)
 {
 
-  INT   i,j;
-  FLOAT diag, sub;
+  ARINT   i,j;
+  ARFLOAT diag, sub;
 
   // Defining constants.
 
-  sub  = 1.0/FLOAT(n+1);
-  diag = 4.0/FLOAT(n+1);
+  sub  = 1.0/6.0/ARFLOAT(n+1);
+  diag = 4.0/6.0/ARFLOAT(n+1);
 
   // Defining the number of nonzero matrix elements.
 
@@ -36,9 +36,9 @@ void MassMatrix(INT n, INT& nnz, FLOAT* &A, INT* &irow, INT* &pcol)
 
   // Creating output vectors.
 
-  A    = new FLOAT[nnz];
-  irow = new INT[nnz];
-  pcol = new INT[n+1];
+  A    = new ARFLOAT[nnz];
+  irow = new ARINT[nnz];
+  pcol = new ARINT[n+1];
 
   // Filling A, irow and pcol.
 
