@@ -1,9 +1,9 @@
 /*
-   ARPACK++ v1.0 8/1/1997
+   ARPACK++ v1.2 2/20/2000
    c++ interface to ARPACK code.
 
    MODULE LNMatrxV.h
-   Function template that generates a  sparse (2n x n) retangular matrix.
+   Function template that generates a  sparse (2n x n) rectangular matrix.
 
    ARPACK Authors
       Richard Lehoucq
@@ -18,13 +18,13 @@
 #define LNMATRXV_H
 
 
-template<class FLOAT, class INT>
-void RetangularMatrix(INT n, INT& m, INT& nnz, FLOAT* &A, 
-                      INT* &irow, INT* &pcol)
+template<class ARFLOAT, class ARINT>
+void RectangularMatrix(ARINT n, ARINT& m, ARINT& nnz, ARFLOAT* &A, 
+                       ARINT* &irow, ARINT* &pcol)
 {
 
-  INT   i, j;
-  FLOAT dd, dl, du;
+  ARINT   i, j;
+  ARFLOAT dd, dl, du;
 
   // Defining constants.
 
@@ -39,9 +39,9 @@ void RetangularMatrix(INT n, INT& m, INT& nnz, FLOAT* &A,
 
   // Creating output vectors.
 
-  A    = new FLOAT[nnz];
-  irow = new INT[nnz];
-  pcol = new INT[n+1];
+  A    = new ARFLOAT[nnz];
+  irow = new ARINT[nnz];
+  pcol = new ARINT[n+1];
 
   // Filling A, irow and pcol.
 
@@ -76,7 +76,7 @@ void RetangularMatrix(INT n, INT& m, INT& nnz, FLOAT* &A,
 
   }
 
-} // Retangular matrix.
+} // Rectangular matrix.
 
 #endif // LNMATRXV_H
 
