@@ -1,5 +1,5 @@
 /*
-   ARPACK++ v1.0 8/1/1997
+   ARPACK++ v1.2 2/20/2000
    c++ interface to ARPACK code.
 
    MODULE BSMatrxC.h
@@ -24,19 +24,19 @@
 
 #include <math.h>
 
-template<class FLOAT, class INT>
-void BandMatrixC(INT n, INT& nD, FLOAT* &A, char uplo='L')
+template<class ARFLOAT, class ARINT>
+void BandMatrixC(ARINT n, ARINT& nD, ARFLOAT* &A, char uplo='L')
 
 {
 
   // Defining internal variables.
 
-  INT    i;
-  FLOAT  h, df, dd;
+  ARINT    i;
+  ARFLOAT  h, df, dd;
 
   // Defining constants.
 
-  h  = 1.0/FLOAT(n+1);
+  h  = 1.0/ARFLOAT(n+1);
   dd = (4.0/6.0)*h;
   df = (1.0/6.0)*h;
 
@@ -46,7 +46,7 @@ void BandMatrixC(INT n, INT& nD, FLOAT* &A, char uplo='L')
 
   // Creating output vector A.
 
-  A   = new FLOAT[2*n];
+  A   = new ARFLOAT[2*n];
 
   if (uplo == 'L') {
 
