@@ -1,5 +1,5 @@
 /*
-   ARPACK++ v1.0 8/1/1997
+   ARPACK++ v1.2 2/20/2000
    c++ interface to ARPACK code.
 
    MODULE DSMatrxC.h
@@ -20,25 +20,25 @@
 
 #include <math.h>
 
-template<class FLOAT, class INT>
-void DenseMatrixC(INT n, FLOAT* &A, char uplo='L')
+template<class ARFLOAT, class ARINT>
+void DenseMatrixC(ARINT n, ARFLOAT* &A, char uplo='L')
 
 {
 
   // Defining internal variables.
 
-  INT    i, j;
-  FLOAT  h, df, dd;
+  ARINT    i, j;
+  ARFLOAT  h, df, dd;
 
   // Defining constants.
 
-  h  = 1.0/FLOAT(n+1);
+  h  = 1.0/ARFLOAT(n+1);
   dd = (4.0/6.0)*h;
   df = (1.0/6.0)*h;
 
   // Creating output vector A.
 
-  A   = new FLOAT[(n*n+n)/2];
+  A   = new ARFLOAT[(n*n+n)/2];
 
   if (uplo == 'L') {
 
