@@ -1,5 +1,5 @@
 /*
-   ARPACK++ v1.0 8/1/1997
+   ARPACK++ v1.2 2/20/2000
    c++ interface to ARPACK code.
 
    MODULE LSMatrxB.h
@@ -20,20 +20,20 @@
 
 #include <math.h>
 
-template<class FLOAT, class INT>
-void SymmetricMatrixB(INT n, INT& nnz, FLOAT* &A, 
-                      INT* &irow, INT* &pcol, char uplo = 'L')
+template<class ARFLOAT, class ARINT>
+void SymmetricMatrixB(ARINT n, ARINT& nnz, ARFLOAT* &A, 
+                      ARINT* &irow, ARINT* &pcol, char uplo = 'L')
 
 {
 
   // Defining internal variables.
 
-  INT    i, j;
-  FLOAT  h2, df, dd;
+  ARINT    i, j;
+  ARFLOAT  h2, df, dd;
 
   // Defining constants.
 
-  h2  = (FLOAT(n+1)*FLOAT(n+1));
+  h2  = (ARFLOAT(n+1)*ARFLOAT(n+1));
   dd = 2.0*h2;
   df = -h2;
 
@@ -43,9 +43,9 @@ void SymmetricMatrixB(INT n, INT& nnz, FLOAT* &A,
 
   // Creating output vectors.
 
-  A    = new FLOAT[nnz];
-  irow = new INT[nnz];
-  pcol = new INT[n+1];
+  A    = new ARFLOAT[nnz];
+  irow = new ARINT[nnz];
+  pcol = new ARINT[n+1];
 
   // Defining matrix A.
 
