@@ -1,5 +1,5 @@
 /*
-   ARPACK++ v1.0 8/1/1997
+   ARPACK++ v1.2 2/20/2000
    c++ interface to ARPACK code.
 
    MODULE LSMatrxD.h
@@ -20,20 +20,20 @@
 
 #include <math.h>
 
-template<class FLOAT, class INT>
-void SymmetricMatrixD(INT n, INT& nnz, FLOAT* &A, 
-                      INT* &irow, INT* &pcol, char uplo = 'L')
+template<class ARFLOAT, class ARINT>
+void SymmetricMatrixD(ARINT n, ARINT& nnz, ARFLOAT* &A, 
+                      ARINT* &irow, ARINT* &pcol, char uplo = 'L')
 
 {
 
   // Defining internal variables.
 
-  INT    i, j;
-  FLOAT  h, df, dd;
+  ARINT    i, j;
+  ARFLOAT  h, df, dd;
 
   // Defining constants.
 
-  h  = 1.0/FLOAT(n+1);
+  h  = 1.0/ARFLOAT(n+1);
   dd = 4.0/6.0*h;
   df = h/6.0;
 
@@ -43,9 +43,9 @@ void SymmetricMatrixD(INT n, INT& nnz, FLOAT* &A,
 
   // Creating output vectors.
 
-  A    = new FLOAT[nnz];
-  irow = new INT[nnz];
-  pcol = new INT[n+1];
+  A    = new ARFLOAT[nnz];
+  irow = new ARINT[nnz];
+  pcol = new ARINT[n+1];
 
   // Defining matrix A.
 
