@@ -1,5 +1,5 @@
 /*
-  ARPACK++ v1.0 8/1/1997
+  ARPACK++ v1.2 2/20/2000
   c++ interface to ARPACK code.
 
   MODULE arcomp.h
@@ -17,22 +17,22 @@
 #ifndef ARCOMP_H
 #define ARCOMP_H
 
-#include <complex.h>
+#include <complex>
 
 #ifdef __GNUG__
   
-#define arcomplex complex
+#define arcomplex std::complex
 
 #endif
 
 #if defined(__SUNPRO_CC) || defined(__sgi)
 
-  template <class FLOAT>
+  template <class ARFLOAT>
   class arcomplex: public complex
   {
    public:
 
-    arcomplex(FLOAT x, FLOAT y): complex(x,y) { }
+    arcomplex(ARFLOAT x, ARFLOAT y): complex(x,y) { }
     arcomplex(): complex() { }
     arcomplex(complex x): complex(x) { }
 
