@@ -1,5 +1,5 @@
 /*
-   ARPACK++ v1.0 8/1/1997
+   ARPACK++ v1.2 2/20/2000
    c++ interface to ARPACK code.
 
    MODULE ARLNSPen.h.
@@ -27,38 +27,39 @@
 #include "arlnsmat.h"
 
 
-template<class TYPE, class FLOAT>
+template<class ARTYPE, class ARFLOAT>
 class ARluNonSymPencil
 {
 
  protected:
 
-  bool                    factored;
-  int*                    permc;
-  int*                    permr;
-  char                    part;
-  ARluNonSymMatrix<TYPE>* A;
-  ARluNonSymMatrix<TYPE>* B;
-  SuperMatrix             L;
-  SuperMatrix             U;
+  bool                               factored;
+  int*                               permc;
+  int*                               permr;
+  char                               part;
+  ARluNonSymMatrix<ARTYPE, ARFLOAT>* A;
+  ARluNonSymMatrix<ARTYPE, ARFLOAT>* B;
+  SuperMatrix                        L;
+  SuperMatrix                        U;
 
   virtual void Copy(const ARluNonSymPencil& other);
 
   void ClearMem();
 
-  void SparseSaxpy(TYPE a, TYPE x[], int xind[], int nx, TYPE y[],
-                   int yind[], int ny, TYPE z[], int zind[], int& nz);
+  void SparseSaxpy(ARTYPE a, ARTYPE x[], int xind[], int nx, ARTYPE y[],
+                   int yind[], int ny, ARTYPE z[], int zind[], int& nz);
 
 #ifdef ARCOMP_H
-  void SparseSaxpy(arcomplex<FLOAT> a, FLOAT x[], int xind[], int nx,
-                   FLOAT y[], int yind[], int ny, arcomplex<FLOAT> z[],
+  void SparseSaxpy(arcomplex<ARFLOAT> a, ARFLOAT x[], int xind[], int nx,
+                   ARFLOAT y[], int yind[], int ny, arcomplex<ARFLOAT> z[],
                    int zind[], int& nz);
 #endif
 
-  void SubtractAsB(int n, TYPE sigma, NCformat& A, NCformat& B, NCformat& AsB);
+  void SubtractAsB(int n, ARTYPE sigma, NCformat& A, 
+                   NCformat& B, NCformat& AsB);
 
 #ifdef ARCOMP_H
-  void SubtractAsB(int n, FLOAT sigmaR, FLOAT sigmaI,
+  void SubtractAsB(int n, ARFLOAT sigmaR, ARFLOAT sigmaI,
                    NCformat& A, NCformat& B, NCformat& AsB);
 #endif
 
@@ -66,30 +67,32 @@ class ARluNonSymPencil
 
   bool IsFactored() { return factored; }
 
-  void FactorAsB(TYPE sigma);
+  void FactorAsB(ARTYPE sigma);
 
 #ifdef ARCOMP_H
-  void FactorAsB(FLOAT sigmaR, FLOAT sigmaI, char partp = 'R');
+  void FactorAsB(ARFLOAT sigmaR, ARFLOAT sigmaI, char partp = 'R');
 #endif
 
-  void MultAv(TYPE* v, TYPE* w) { A->MultMv(v,w); }
+  void MultAv(ARTYPE* v, ARTYPE* w) { A->MultMv(v,w); }
 
-  void MultBv(TYPE* v, TYPE* w) { B->MultMv(v,w); }
+  void MultBv(ARTYPE* v, ARTYPE* w) { B->MultMv(v,w); }
 
-  void MultInvBAv(TYPE* v, TYPE* w);
+  void MultInvBAv(ARTYPE* v, ARTYPE* w);
 
 #ifdef ARCOMP_H
-  void MultInvAsBv(arcomplex<FLOAT>* v, arcomplex<FLOAT>* w);
+  void MultInvAsBv(arcomplex<ARFLOAT>* v, arcomplex<ARFLOAT>* w);
 #endif
 
-  void MultInvAsBv(FLOAT* v, FLOAT* w);
+  void MultInvAsBv(ARFLOAT* v, ARFLOAT* w);
 
-  void DefineMatrices(ARluNonSymMatrix<TYPE>& Ap, ARluNonSymMatrix<TYPE>& Bp);
+  void DefineMatrices(ARluNonSymMatrix<ARTYPE, ARFLOAT>& Ap, 
+                      ARluNonSymMatrix<ARTYPE, ARFLOAT>& Bp);
 
   ARluNonSymPencil();
   // Short constructor that does nothing.
 
-  ARluNonSymPencil(ARluNonSymMatrix<TYPE>& Ap, ARluNonSymMatrix<TYPE>& Bp);
+  ARluNonSymPencil(ARluNonSymMatrix<ARTYPE, ARFLOAT>& Ap, 
+                   ARluNonSymMatrix<ARTYPE, ARFLOAT>& Bp);
   // Long constructor.
 
   ARluNonSymPencil(const ARluNonSymPencil& other) { Copy(other); }
@@ -108,9 +111,9 @@ class ARluNonSymPencil
 // ------------------------------------------------------------------------ //
 
 
-template<class TYPE, class FLOAT>
-inline void ARluNonSymPencil<TYPE, FLOAT>::
-Copy(const ARluNonSymPencil<TYPE, FLOAT>& other)
+template<class ARTYPE, class ARFLOAT>
+inline void ARluNonSymPencil<ARTYPE, ARFLOAT>::
+Copy(const ARluNonSymPencil<ARTYPE, ARFLOAT>& other)
 {
 
   factored = other.factored;
@@ -132,8 +135,8 @@ Copy(const ARluNonSymPencil<TYPE, FLOAT>& other)
 } // Copy.
 
 
-template<class TYPE, class FLOAT>
-void ARluNonSymPencil<TYPE, FLOAT>::ClearMem()
+template<class ARTYPE, class ARFLOAT>
+void ARluNonSymPencil<ARTYPE, ARFLOAT>::ClearMem()
 {
 
   if (factored) {
@@ -149,17 +152,17 @@ void ARluNonSymPencil<TYPE, FLOAT>::ClearMem()
 } // ClearMem.
 
 
-template<class TYPE, class FLOAT>
-void ARluNonSymPencil<TYPE, FLOAT>::
-SparseSaxpy(TYPE a, TYPE x[], int xind[], int nx, TYPE y[],
-            int yind[], int ny, TYPE z[], int zind[], int& nz)
+template<class ARTYPE, class ARFLOAT>
+void ARluNonSymPencil<ARTYPE, ARFLOAT>::
+SparseSaxpy(ARTYPE a, ARTYPE x[], int xind[], int nx, ARTYPE y[],
+            int yind[], int ny, ARTYPE z[], int zind[], int& nz)
 // A strongly sequential (and inefficient) sparse saxpy algorithm.
 {
 
   int ix, iy;
 
   nz = 0;
-  if ((nx == 0) || (a == (TYPE)0)) {
+  if ((nx == 0) || (a == (ARTYPE)0)) {
     copy(ny,y,1,z,1);
     for (iy=0; iy!=ny; iy++) zind[iy] = yind[iy];
     nz = ny;
@@ -200,23 +203,23 @@ SparseSaxpy(TYPE a, TYPE x[], int xind[], int nx, TYPE y[],
     z[nz++]  = x[ix++];
   }
 
-} // SparseSaxpy (TYPE).
+} // SparseSaxpy (ARTYPE).
 
 
 #ifdef ARCOMP_H
-template<class TYPE, class FLOAT>
-void ARluNonSymPencil<TYPE, FLOAT>::
-SparseSaxpy(arcomplex<FLOAT> a, FLOAT x[], int xind[], int nx, FLOAT y[],
-            int yind[], int ny, arcomplex<FLOAT> z[], int zind[], int& nz)
+template<class ARTYPE, class ARFLOAT>
+void ARluNonSymPencil<ARTYPE, ARFLOAT>::
+SparseSaxpy(arcomplex<ARFLOAT> a, ARFLOAT x[], int xind[], int nx, ARFLOAT y[],
+            int yind[], int ny, arcomplex<ARFLOAT> z[], int zind[], int& nz)
 // A strongly sequential (and inefficient) sparse saxpy algorithm.
 {
 
   int ix, iy;
 
   nz = 0;
-  if ((nx == 0) || (a == arcomplex<FLOAT>(0.0,0.0))) {
+  if ((nx == 0) || (a == arcomplex<ARFLOAT>(0.0,0.0))) {
     for (iy=0; iy!=ny; iy++) {
-      z[iy]    = arcomplex<FLOAT>(y[iy],0.0);
+      z[iy]    = arcomplex<ARFLOAT>(y[iy],0.0);
       zind[iy] = yind[iy];
     }
     nz = ny;
@@ -224,7 +227,7 @@ SparseSaxpy(arcomplex<FLOAT> a, FLOAT x[], int xind[], int nx, FLOAT y[],
   }
   if (ny == 0) {
     for (ix=0; ix!=ny; ix++) {
-      z[ix]    = a*arcomplex<FLOAT>(x[ix],0.0);
+      z[ix]    = a*arcomplex<ARFLOAT>(x[ix],0.0);
       zind[ix] = xind[ix];
     }
     nz = nx;
@@ -245,38 +248,38 @@ SparseSaxpy(arcomplex<FLOAT> a, FLOAT x[], int xind[], int nx, FLOAT y[],
     }
     else {
       zind[nz] = yind[iy];
-      z[nz++]  = arcomplex<FLOAT>(y[iy++],0.0);
+      z[nz++]  = arcomplex<ARFLOAT>(y[iy++],0.0);
       if (iy == ny) break;
     }
   }
   while (iy < ny) {
     zind[nz] = yind[iy];
-    z[nz++]  = arcomplex<FLOAT>(y[iy++],0.0);
+    z[nz++]  = arcomplex<ARFLOAT>(y[iy++],0.0);
   }
   while (ix < nx) {
     zind[nz] = xind[ix];
-    z[nz++]  = arcomplex<FLOAT>(x[ix++],0.0);
+    z[nz++]  = arcomplex<ARFLOAT>(x[ix++],0.0);
   }
 
-} // SparseSaxpy (arcomplex<FLOAT>).
+} // SparseSaxpy (arcomplex<ARFLOAT>).
 #endif // ARCOMP_H.
 
 
-template<class TYPE, class FLOAT>
-void ARluNonSymPencil<TYPE, FLOAT>::
-SubtractAsB(int n, TYPE sigma, NCformat& A, NCformat& B, NCformat& AsB)
+template<class ARTYPE, class ARFLOAT>
+void ARluNonSymPencil<ARTYPE, ARFLOAT>::
+SubtractAsB(int n, ARTYPE sigma, NCformat& A, NCformat& B, NCformat& AsB)
 {
 
-  int   i, acol, bcol, asbcol, scol;
-  TYPE* anzval;
-  TYPE* bnzval;
-  TYPE* asbnzval;
+  int     i, acol, bcol, asbcol, scol;
+  ARTYPE* anzval;
+  ARTYPE* bnzval;
+  ARTYPE* asbnzval;
 
-  // Telling the compiler that nzval must ve viewed as a vector of TYPE.
+  // Telling the compiler that nzval must ve viewed as a vector of ARTYPE.
 
-  anzval   = (TYPE*)A.nzval;
-  bnzval   = (TYPE*)B.nzval;
-  asbnzval = (TYPE*)AsB.nzval;
+  anzval   = (ARTYPE*)A.nzval;
+  bnzval   = (ARTYPE*)B.nzval;
+  asbnzval = (ARTYPE*)AsB.nzval;
 
   // Subtracting sigma*B from A.
 
@@ -295,31 +298,31 @@ SubtractAsB(int n, TYPE sigma, NCformat& A, NCformat& B, NCformat& AsB)
 
   AsB.nnz = AsB.colptr[n];
 
-} // SubtractAsB (TYPE shift).
+} // SubtractAsB (ARTYPE shift).
 
 
 #ifdef ARCOMP_H
-template<class TYPE, class FLOAT>
-void ARluNonSymPencil<TYPE, FLOAT>::
-SubtractAsB(int n, FLOAT sigmaR, FLOAT sigmaI,
+template<class ARTYPE, class ARFLOAT>
+void ARluNonSymPencil<ARTYPE, ARFLOAT>::
+SubtractAsB(int n, ARFLOAT sigmaR, ARFLOAT sigmaI,
             NCformat& A, NCformat& B, NCformat& AsB)
 {
 
-  int               i, acol, bcol, asbcol, scol;
-  TYPE*             anzval;
-  TYPE*             bnzval;
-  arcomplex<FLOAT>* asbnzval;
-  arcomplex<FLOAT>  sigma;
+  int                 i, acol, bcol, asbcol, scol;
+  ARTYPE*             anzval;
+  ARTYPE*             bnzval;
+  arcomplex<ARFLOAT>* asbnzval;
+  arcomplex<ARFLOAT>  sigma;
 
-  // Telling the compiler that nzval must ve viewed as a vector of TYPE.
+  // Telling the compiler that nzval must ve viewed as a vector of ARTYPE.
 
-  anzval   = (TYPE*)A.nzval;
-  bnzval   = (TYPE*)B.nzval;
-  asbnzval = (arcomplex<FLOAT>*)AsB.nzval;
+  anzval   = (ARTYPE*)A.nzval;
+  bnzval   = (ARTYPE*)B.nzval;
+  asbnzval = (arcomplex<ARFLOAT>*)AsB.nzval;
 
   // Subtracting sigma*B from A.
 
-  sigma         = arcomplex<FLOAT>(sigmaR, sigmaI);
+  sigma         = arcomplex<ARFLOAT>(sigmaR, sigmaI);
   AsB.colptr[0] = 0;
   asbcol        = 0;
 
@@ -335,12 +338,12 @@ SubtractAsB(int n, FLOAT sigmaR, FLOAT sigmaI,
 
   AsB.nnz = AsB.colptr[n];
 
-} // SubtractAsB (arcomplex<FLOAT> shift).
+} // SubtractAsB (arcomplex<ARFLOAT> shift).
 #endif // ARCOMP_H.
 
 
-template<class TYPE, class FLOAT>
-void ARluNonSymPencil<TYPE, FLOAT>::FactorAsB(TYPE sigma)
+template<class ARTYPE, class ARFLOAT>
+void ARluNonSymPencil<ARTYPE, ARFLOAT>::FactorAsB(ARTYPE sigma)
 {
 
   // Quitting the function if A and B were not defined.
@@ -363,7 +366,7 @@ void ARluNonSymPencil<TYPE, FLOAT>::FactorAsB(TYPE sigma)
   int*        etree;
   int*        irowi;
   int*        pcoli;
-  TYPE*       asb;
+  ARTYPE*     asb;
   SuperMatrix AsB;
   SuperMatrix AC;
   NCformat*   Astore;
@@ -376,7 +379,7 @@ void ARluNonSymPencil<TYPE, FLOAT>::FactorAsB(TYPE sigma)
 
   // Setting default values for gstrf parameters.
 
-  FLOAT drop_tol        = 0.0;
+  ARFLOAT drop_tol        = 0.0;
   int   panel_size      = sp_ienv(1);
   int   relax           = sp_ienv(2);
 
@@ -390,7 +393,7 @@ void ARluNonSymPencil<TYPE, FLOAT>::FactorAsB(TYPE sigma)
   nnzi  = Astore->nnz+Bstore->nnz;
   irowi = new int[nnzi];
   pcoli = new int[A->ncols()+1];
-  asb   = new TYPE[nnzi];
+  asb   = new ARTYPE[nnzi];
   Create_CompCol_Matrix(&AsB, A->nrows(), A->ncols(), nnzi, asb,
                         irowi, pcoli, NC, GE);
 
@@ -407,7 +410,6 @@ void ARluNonSymPencil<TYPE, FLOAT>::FactorAsB(TYPE sigma)
 
   // Defining LUStat.
 
-  extern SuperLUStat_t SuperLUStat;
   StatInit(panel_size, relax);
 
   // Defining the column permutation of matrix AsB
@@ -448,13 +450,13 @@ void ARluNonSymPencil<TYPE, FLOAT>::FactorAsB(TYPE sigma)
                       "ARluNonSymPencil::FactorAsB");
   }
 
-} // FactorAsB (TYPE shift).
+} // FactorAsB (ARTYPE shift).
 
 
 #ifdef ARCOMP_H
-template<class TYPE, class FLOAT>
-void ARluNonSymPencil<TYPE, FLOAT>::
-FactorAsB(FLOAT sigmaR, FLOAT sigmaI, char partp)
+template<class ARTYPE, class ARFLOAT>
+void ARluNonSymPencil<ARTYPE, ARFLOAT>::
+FactorAsB(ARFLOAT sigmaR, ARFLOAT sigmaI, char partp)
 {
 
   // Quitting the function if A and B were not defined.
@@ -473,16 +475,16 @@ FactorAsB(FLOAT sigmaR, FLOAT sigmaI, char partp)
 
   // Defining local variables.
 
-  int               nnzi, info;
-  int*              etree;
-  int*              irowi;
-  int*              pcoli;
-  arcomplex<FLOAT>* asb;
-  SuperMatrix       AsB;
-  SuperMatrix       AC;
-  NCformat*         Astore;
-  NCformat*         Bstore;
-  NCformat*         AsBstore;
+  int                 nnzi, info;
+  int*                etree;
+  int*                irowi;
+  int*                pcoli;
+  arcomplex<ARFLOAT>* asb;
+  SuperMatrix         AsB;
+  SuperMatrix         AC;
+  NCformat*           Astore;
+  NCformat*           Bstore;
+  NCformat*           AsBstore;
 
   // Deleting old versions of L, U, perm_r and perm_c.
 
@@ -490,7 +492,7 @@ FactorAsB(FLOAT sigmaR, FLOAT sigmaI, char partp)
 
   // Setting default values for gstrf parameters.
 
-  FLOAT drop_tol        = 0.0;
+  ARFLOAT drop_tol      = 0.0;
   int   panel_size      = sp_ienv(1);
   int   relax           = sp_ienv(2);
 
@@ -505,7 +507,7 @@ FactorAsB(FLOAT sigmaR, FLOAT sigmaI, char partp)
   nnzi  = Astore->nnz+Bstore->nnz;
   irowi = new int[nnzi];
   pcoli = new int[A->ncols()+1];
-  asb   = new arcomplex<FLOAT>[nnzi];
+  asb   = new arcomplex<ARFLOAT>[nnzi];
   Create_CompCol_Matrix(&AsB, A->nrows(), A->ncols(), nnzi, asb,
                         irowi, pcoli, NC, GE);
 
@@ -522,7 +524,6 @@ FactorAsB(FLOAT sigmaR, FLOAT sigmaI, char partp)
 
   // Defining LUStat.
 
-  extern SuperLUStat_t SuperLUStat;
   StatInit(panel_size, relax);
 
   // Defining the column permutation of matrix AsB
@@ -563,12 +564,12 @@ FactorAsB(FLOAT sigmaR, FLOAT sigmaI, char partp)
                       "ARluNonSymPencil::FactorAsB");
   }
 
-} // FactorAsB (arcomplex<FLOAT> shift).
+} // FactorAsB (arcomplex<ARFLOAT> shift).
 #endif // ARCOMP_H.
 
 
-template<class TYPE, class FLOAT>
-void ARluNonSymPencil<TYPE, FLOAT>::MultInvBAv(TYPE* v, TYPE* w)
+template<class ARTYPE, class ARFLOAT>
+void ARluNonSymPencil<ARTYPE, ARFLOAT>::MultInvBAv(ARTYPE* v, ARTYPE* w)
 {
 
   if (!B->IsFactored()) B->FactorA();
@@ -581,9 +582,9 @@ void ARluNonSymPencil<TYPE, FLOAT>::MultInvBAv(TYPE* v, TYPE* w)
 
 #ifdef ARCOMP_H
 
-template<class TYPE, class FLOAT>
-void ARluNonSymPencil<TYPE, FLOAT>::
-MultInvAsBv(arcomplex<FLOAT>* v, arcomplex<FLOAT>* w)
+template<class ARTYPE, class ARFLOAT>
+void ARluNonSymPencil<ARTYPE, ARFLOAT>::
+MultInvAsBv(arcomplex<ARFLOAT>* v, arcomplex<ARFLOAT>* w)
 {
 
   // Quitting the function if AsB was not factored.
@@ -602,15 +603,15 @@ MultInvAsBv(arcomplex<FLOAT>* v, arcomplex<FLOAT>* w)
   Create_Dense_Matrix(&RHS, A->nrows(), 1, w, A->nrows(), DN, GE);
   gstrs("N", &L, &U, permr, permc, &RHS, &info);
 
-  delete RHS.Store;
+  Destroy_SuperMatrix_Store(&RHS); // delete RHS.Store;
 
-} // MultInvAsBv (arcomplex<FLOAT>).
+} // MultInvAsBv (arcomplex<ARFLOAT>).
 
 #endif
 
 
-template<class TYPE, class FLOAT>
-void ARluNonSymPencil<TYPE, FLOAT>::MultInvAsBv(FLOAT* v, FLOAT* w)
+template<class ARTYPE, class ARFLOAT>
+void ARluNonSymPencil<ARTYPE, ARFLOAT>::MultInvAsBv(ARFLOAT* v, ARFLOAT* w)
 {
 
   // Quitting the function if AsB was not factored.
@@ -636,10 +637,10 @@ void ARluNonSymPencil<TYPE, FLOAT>::MultInvAsBv(FLOAT* v, FLOAT* w)
 
 #ifdef ARCOMP_H
 
-    int              i;
-    arcomplex<FLOAT> *tv = new arcomplex<FLOAT>[A->ncols()];
+    int                i;
+    arcomplex<ARFLOAT> *tv = new arcomplex<ARFLOAT>[A->ncols()];
 
-    for (i=0; i!=A->ncols(); i++) tv[i] = arcomplex<FLOAT>(v[i],0.0);
+    for (i=0; i!=A->ncols(); i++) tv[i] = arcomplex<ARFLOAT>(v[i],0.0);
     Create_Dense_Matrix(&RHS, A->ncols(), 1, tv, A->ncols(), DN, GE);
     gstrs("N", &L, &U, permr, permc, &RHS, &info);
 
@@ -656,14 +657,15 @@ void ARluNonSymPencil<TYPE, FLOAT>::MultInvAsBv(FLOAT* v, FLOAT* w)
 
   }
 
-  delete RHS.Store;
+  Destroy_SuperMatrix_Store(&RHS); // delete RHS.Store;
 
-} // MultInvAsBv (FLOAT).
+} // MultInvAsBv (ARFLOAT).
 
 
-template<class TYPE, class FLOAT>
-inline void ARluNonSymPencil<TYPE, FLOAT>::
-DefineMatrices(ARluNonSymMatrix<TYPE>& Ap, ARluNonSymMatrix<TYPE>& Bp)
+template<class ARTYPE, class ARFLOAT>
+inline void ARluNonSymPencil<ARTYPE, ARFLOAT>::
+DefineMatrices(ARluNonSymMatrix<ARTYPE, ARFLOAT>& Ap, 
+               ARluNonSymMatrix<ARTYPE, ARFLOAT>& Bp)
 {
 
   A     = &Ap;
@@ -679,8 +681,8 @@ DefineMatrices(ARluNonSymMatrix<TYPE>& Ap, ARluNonSymMatrix<TYPE>& Bp)
 } // DefineMatrices.
 
 
-template<class TYPE, class FLOAT>
-inline ARluNonSymPencil<TYPE, FLOAT>::ARluNonSymPencil()
+template<class ARTYPE, class ARFLOAT>
+inline ARluNonSymPencil<ARTYPE, ARFLOAT>::ARluNonSymPencil()
 {
   
   factored = false; 
@@ -691,9 +693,10 @@ inline ARluNonSymPencil<TYPE, FLOAT>::ARluNonSymPencil()
 } // Short constructor.
 
 
-template<class TYPE, class FLOAT>
-inline ARluNonSymPencil<TYPE, FLOAT>::
-ARluNonSymPencil(ARluNonSymMatrix<TYPE>& Ap, ARluNonSymMatrix<TYPE>& Bp)
+template<class ARTYPE, class ARFLOAT>
+inline ARluNonSymPencil<ARTYPE, ARFLOAT>::
+ARluNonSymPencil(ARluNonSymMatrix<ARTYPE, ARFLOAT>& Ap, 
+                 ARluNonSymMatrix<ARTYPE, ARFLOAT>& Bp)
 {
 
   factored = false;
@@ -702,9 +705,9 @@ ARluNonSymPencil(ARluNonSymMatrix<TYPE>& Ap, ARluNonSymMatrix<TYPE>& Bp)
 } // Long constructor.
 
 
-template<class TYPE, class FLOAT>
-ARluNonSymPencil<TYPE, FLOAT>& ARluNonSymPencil<TYPE, FLOAT>::
-operator=(const ARluNonSymPencil<TYPE, FLOAT>& other)
+template<class ARTYPE, class ARFLOAT>
+ARluNonSymPencil<ARTYPE, ARFLOAT>& ARluNonSymPencil<ARTYPE, ARFLOAT>::
+operator=(const ARluNonSymPencil<ARTYPE, ARFLOAT>& other)
 {
 
   if (this != &other) { // Stroustrup suggestion.
