@@ -1,5 +1,5 @@
 /*
-   ARPACK++ v1.0 8/1/1997
+   ARPACK++ v1.2 2/20/2000
    c++ interface to ARPACK code.
 
    MODULE ARLSpDef.h.
@@ -19,8 +19,10 @@
 #include "arlnames.h"
 #include "arlsupm.h"
 #include "arlcomp.h"
-
-#define USE_VENDOR_BLAS
+#ifdef _CRAY
+#include <fortran.h>
+#include <string.h>
+#endif
 
 /* No of marker arrays used in the symbolic factorization,
    each of size n */
@@ -83,6 +85,7 @@ typedef enum {SYSTEM, USER}            LU_space_t;
  *	xusub[i] points to the starting location of column i in ucol.
  *	Storage: new row subscripts; that is subscripts of PA.
  */
+
 typedef struct {
     int     *xsup;    /* supernode and column mapping */
     int     *supno;   
@@ -271,18 +274,20 @@ cCopy_Dense_Matrix(int, int, lscomplex *, int, lscomplex *, int);
 extern void
 zCopy_Dense_Matrix(int, int, ldcomplex *, int, ldcomplex *, int);
 
+extern void    Destroy_SuperMatrix_Store(SuperMatrix *);
 extern void    Destroy_CompCol_Matrix(SuperMatrix *);
 extern void    Destroy_SuperNode_Matrix(SuperMatrix *);
 extern void    Destroy_CompCol_Permuted(SuperMatrix *);
+extern void    Destroy_Dense_Matrix(SuperMatrix *);
+extern void    get_perm_c(int, SuperMatrix *, int *);  
+extern void    sp_preorder (char*, SuperMatrix*, int*, int*, SuperMatrix*);
+//  extern void    countnz (const int, int *, int *, int *, sGlobalLU_t *);
+//  extern void    fixupL (const int, const int *, sGlobalLU_t *);
 
 extern void    sallocateA (int, int, float **, int **, int **);
 extern void    dallocateA (int, int, double **, int **, int **);
 extern void    callocateA (int, int, lscomplex **, int **, int **);
 extern void    zallocateA (int, int, ldcomplex **, int **, int **);
-extern void    StatInit    (int, int);
-extern void    StatFree    ();
-extern void    sp_preorder (char*, SuperMatrix*, int*, int*, SuperMatrix*);
-extern int     sp_coletree (int *, int *, int *, int, int, int *);
 extern void    sgstrf (char*, SuperMatrix*, float, float, int, int, int*,
 			void *, int, int *, int *, 
                         SuperMatrix *, SuperMatrix *, int *);
@@ -295,7 +300,6 @@ extern void    cgstrf (char*, SuperMatrix*, float, float, int, int, int*,
 extern void    zgstrf (char*, SuperMatrix*, double, double, int, int, int*,
 			void *, int, int *, int *, 
                         SuperMatrix *, SuperMatrix *, int *);
-extern void    relax_snode  (int, int *, int, int *, int *);
 extern int     ssnode_dfs (const int, const int, const int *, const int *,
 			     const int *, int *, int *, sGlobalLU_t *);
 extern int     dsnode_dfs (const int, const int, const int *, const int *,
@@ -376,11 +380,6 @@ extern void    cpruneL (const int, const int *, const int, const int,
 			     const int *, const int *, int *, cGlobalLU_t *);
 extern void    zpruneL (const int, const int *, const int, const int,
 			     const int *, const int *, int *, zGlobalLU_t *);
-extern void    resetrep_col (const int, const int *, int *);
-//    extern void    countnz (const int, int *, int *, int *, sGlobalLU_t *);
-//    extern void    fixupL (const int, const int *, sGlobalLU_t *);
-extern int     spcoletree (int *, int *, int *, int, int, int *);
-extern int     *TreePostorder (int, int *);
 extern void    sreadmt (int *, int *, int *, float **, int **, int **);
 extern void    dreadmt (int *, int *, int *, double **, int **, int **);
 extern void    creadmt (int *, int *, int *, lscomplex **, int **, int **);
@@ -433,6 +432,14 @@ extern void    cgscon (char *, SuperMatrix *, SuperMatrix *,
 			float, float *, int *);
 extern void    zgscon (char *, SuperMatrix *, SuperMatrix *,
 			double, double *, int *);
+extern float   sPivotGrowth(int, SuperMatrix *, int *, 
+                            SuperMatrix *, SuperMatrix *);
+extern double  dPivotGrowth(int, SuperMatrix *, int *, 
+                            SuperMatrix *, SuperMatrix *);
+extern float   cPivotGrowth(int, SuperMatrix *, int *, 
+                            SuperMatrix *, SuperMatrix *);
+extern double  zPivotGrowth(int, SuperMatrix *, int *, 
+                            SuperMatrix *, SuperMatrix *);
 extern void    sgsrfs (char *, SuperMatrix *, SuperMatrix *,
 			SuperMatrix *, int *, int *, char *, float *, 
 			float *, SuperMatrix *, SuperMatrix *, float *,
@@ -481,8 +488,6 @@ extern int     sp_zgemm (char *, char *, int, int, int, ldcomplex,
 			ldcomplex *, int);
 
 /* Memory-related */
-extern void    *superlu_malloc (int);
-extern void    superlu_free (void*);
 extern int     sLUMemInit (char *, void *, int, int, int, int, int,
 			     SuperMatrix *, SuperMatrix *,
 			     sGlobalLU_t *, int **, float **);
@@ -495,8 +500,6 @@ extern int     cLUMemInit (char *, void *, int, int, int, int, int,
 extern int     zLUMemInit (char *, void *, int, int, int, int, int,
 			     SuperMatrix *, SuperMatrix *,
 			     zGlobalLU_t *, int **, ldcomplex **);
-extern void    SetIWork (int, int, int, int *, int **, int **, int **,
-                         int **, int **, int **, int **);
 extern void    sSetRWork (int, int, float *, float **, float **);
 extern void    dSetRWork (int, int, double *, double **, double **);
 extern void    cSetRWork (int, int, lscomplex *, lscomplex **, lscomplex **);
@@ -510,8 +513,6 @@ extern int     dLUMemXpand (int, int, MemType, int *, dGlobalLU_t *);
 extern int     cLUMemXpand (int, int, MemType, int *, cGlobalLU_t *);
 extern int     zLUMemXpand (int, int, MemType, int *, zGlobalLU_t *);
 
-extern int     *intMalloc (int);
-extern int     *intCalloc (int);
 extern float  *floatMalloc(int);
 extern double  *doubleMalloc(int);
 extern lscomplex  *complexMalloc(int);
@@ -520,8 +521,10 @@ extern float  *floatCalloc(int);
 extern double  *doubleCalloc(int);
 extern lscomplex  *complexCalloc(int);
 extern ldcomplex  *doublecomplexCalloc(int);
-extern void    *superlu_malloc(int);
-extern int     memory_usage();
+extern int     smemory_usage(const int, const int, const int, const int);
+extern int     dmemory_usage(const int, const int, const int, const int);
+extern int     cmemory_usage(const int, const int, const int, const int);
+extern int     zmemory_usage(const int, const int, const int, const int);
 extern int     sQuerySpace (SuperMatrix *, SuperMatrix *, int,
 				mem_usage_t *);
 extern int     dQuerySpace (SuperMatrix *, SuperMatrix *, int,
@@ -532,31 +535,47 @@ extern int     zQuerySpace (SuperMatrix *, SuperMatrix *, int,
 				mem_usage_t *);
 
 /* Auxiliary routines */
-extern double  SuperLU_timer_ ();
-extern int     sp_ienv (int);
-extern int     lsame_ (char *, char *);
-extern int     xerbla_ (char *, int *);
-extern void    ifill (int *, int, int);
+extern void    sreadhb(int *, int *, int *, float **, int **, int **);
+extern void    dreadhb(int *, int *, int *, double **, int **, int **);
+extern void    creadhb(int *, int *, int *, lscomplex **, int **, int **);
+extern void    zreadhb(int *, int *, int *, ldcomplex **, int **, int **);
+extern void    sCompRow_to_CompCol(int, int, int, float*, int*, int*,
+		                   float **, int **, int **);
+extern void    dCompRow_to_CompCol(int, int, int, double*, int*, int*,
+		                   double **, int **, int **);
+extern void    cCompRow_to_CompCol(int, int, int, lscomplex*, int*, int*,
+		                   lscomplex **, int **, int **);
+extern void    zCompRow_to_CompCol(int, int, int, ldcomplex*, int*, int*,
+		                   ldcomplex **, int **, int **);
 extern void    sfill (float *, int, float);
 extern void    dfill (double *, int, double);
 extern void    cfill (lscomplex *, int, lscomplex);
 extern void    zfill (ldcomplex *, int, ldcomplex);
-//     extern void    inf_norm_error (int, SuperMatrix *, float *);
-extern void    snode_profile (int, int *);
-extern void    super_stats (int, int *);
-extern void    PrintSumm (char *, int, int, int);
-//     extern void    PrintPerf (SuperMatrix *, SuperMatrix *, mem_usage_t *,
-//	         		 float, float, float *, float *, char *);
+extern void    sinf_norm_error (int, SuperMatrix *, float *);
+extern void    dinf_norm_error (int, SuperMatrix *, double *);
+extern void    cinf_norm_error (int, SuperMatrix *, lscomplex *);
+extern void    zinf_norm_error (int, SuperMatrix *, ldcomplex *);
+//  extern void    PrintPerf (SuperMatrix *, SuperMatrix *, mem_usage_t *,
+//                           float, float, float *, float *, char *);
 
 /* Routines for debugging */
+extern void    sPrint_CompCol_Matrix(char *, SuperMatrix *);
+extern void    dPrint_CompCol_Matrix(char *, SuperMatrix *);
+extern void    cPrint_CompCol_Matrix(char *, SuperMatrix *);
+extern void    zPrint_CompCol_Matrix(char *, SuperMatrix *);
+extern void    sPrint_SuperNode_Matrix(char *, SuperMatrix *);
+extern void    dPrint_SuperNode_Matrix(char *, SuperMatrix *);
+extern void    cPrint_SuperNode_Matrix(char *, SuperMatrix *);
+extern void    zPrint_SuperNode_Matrix(char *, SuperMatrix *);
+extern void    sPrint_Dense_Matrix(char *, SuperMatrix *);
+extern void    dPrint_Dense_Matrix(char *, SuperMatrix *);
+extern void    cPrint_Dense_Matrix(char *, SuperMatrix *);
+extern void    zPrint_Dense_Matrix(char *, SuperMatrix *);
 //     extern void    print_lu_col(char *, int, int, int *, sGlobalLU_t *);
-extern void    print_panel_seg(int, int, int, int, int *, int *);
 //     extern void    check_tempv(int, float *);
-extern void    check_repfnz(int, int, int, int *);
 
 /* Reordering routine */
 
-extern void    get_perm_c(int, SuperMatrix *, int *);  
 
 #ifdef __cplusplus
   }
