@@ -1,5 +1,5 @@
 /*
-   ARPACK++ v1.0 8/1/1997
+   ARPACK++ v1.2 2/20/2000
    c++ interface to ARPACK code.
 
    MODULE ARMat.h
@@ -17,7 +17,7 @@
 #ifndef ARMAT_H
 #define ARMAT_H
 
-template<class TYPE>
+template<class ARTYPE>
 class ARMatrix {
 
  protected:
@@ -47,7 +47,7 @@ class ARMatrix {
 
   bool IsDefined() { return defined; }
 
-  virtual void MultMv(TYPE* v, TYPE* w) = 0;
+  virtual void MultMv(ARTYPE* v, ARTYPE* w) = 0;
   // Matrix-vector product: w = A*v.
 
 }; // ARMatrix.
