@@ -1,5 +1,5 @@
 /*
-   ARPACK++ v1.0 8/1/1997
+   ARPACK++ v1.2 2/20/2000
    c++ interface to ARPACK code.
 
    MODULE ARRSEig.h.
@@ -19,8 +19,9 @@
 #ifndef ARRSEIG_H
 #define ARRSEIG_H
 
-#include <new.h>
-#include <stddef.h>
+#include <new>
+#include <cstddef>
+
 #include "arch.h"
 #include "arerror.h"
 #include "debug.h"
@@ -29,11 +30,11 @@
 
 // "New" handler.
 
-void MemoryOverflow() { throw ArpackError(ArpackError::MEMORY_OVERFLOW); }
+void MemoryOverflow() throw();
 
 // ARrcStdEig class definition.
 
-template<class FLOAT, class TYPE>
+template<class ARFLOAT, class ARTYPE>
 class ARrcStdEig {
 
  protected:
@@ -47,10 +48,10 @@ class ARrcStdEig {
   int     ncv;        // Number of Arnoldi vectors generated at each iteration.
   int     maxit;      // Maximum number of Arnoldi update iterations allowed.
   char*   which;      // Specify which of the Ritz values of OP to compute.
-  FLOAT   tol;        // Stopping criterion (relative accuracy of Ritz values).
-  FLOAT   sigmaI;     // Imaginary part of shift (for nonsymmetric problems).
-  TYPE    sigmaR;     // Shift (real part only if problem is nonsymmetric).
-  TYPE    *resid;     // Initial residual vector.
+  ARFLOAT tol;        // Stopping criterion (relative accuracy of Ritz values).
+  ARFLOAT sigmaI;     // Imaginary part of shift (for nonsymmetric problems).
+  ARTYPE  sigmaR;     // Shift (real part only if problem is nonsymmetric).
+  ARTYPE  *resid;     // Initial residual vector.
 
 
  // a.2) Internal variables.
@@ -80,19 +81,19 @@ class ARrcStdEig {
   int     lrwork;     // Dimension of array rwork.
   int     iparam[12]; // Vector that handles original ARPACK parameters.
   int     ipntr[15];  // Vector that handles original ARPACK pointers.
-  FLOAT   *rwork;     // Original ARPACK internal vector.
-  TYPE    *workl;     // Original ARPACK internal vector.
-  TYPE    *workd;     // Original ARPACK internal vector.
-  TYPE    *workv;     // Original ARPACK internal vector.
-  TYPE    *V;         // Arnoldi basis / Schur vectors.
+  ARFLOAT *rwork;     // Original ARPACK internal vector.
+  ARTYPE  *workl;     // Original ARPACK internal vector.
+  ARTYPE  *workd;     // Original ARPACK internal vector.
+  ARTYPE  *workv;     // Original ARPACK internal vector.
+  ARTYPE  *V;         // Arnoldi basis / Schur vectors.
 
 
  // a.3) Pure output variables.
 
   int     nconv;      // Number of "converged" Ritz values.
-  FLOAT   *EigValI;   // Imaginary part of eigenvalues (nonsymmetric problems).
-  TYPE    *EigValR;   // Eigenvalues (real part only if problem is nonsymmetric).
-  TYPE    *EigVec;    // Eigenvectors.
+  ARFLOAT *EigValI;   // Imaginary part of eigenvalues (nonsymmetric problems).
+  ARTYPE  *EigValR;   // Eigenvalues (real part only if problem is nonsymmetric).
+  ARTYPE  *EigVec;    // Eigenvectors.
 
 
  // b) Protected functions:
@@ -189,8 +190,8 @@ class ARrcStdEig {
  // c.1) Function that stores user defined parameters.
 
   virtual void DefineParameters(int np, int nevp, char* whichp="LM",
-                                int ncvp=0, FLOAT tolp=0.0, int maxitp=0,
-                                TYPE* residp=NULL, bool ishiftp=true);
+                                int ncvp=0, ARFLOAT tolp=0.0, int maxitp=0,
+                                ARTYPE* residp=NULL, bool ishiftp=true);
   // Set values of problem parameters (also called by constructors).
   // Redefined in ARrcStdEig and ARrcGenEig.
 
@@ -224,7 +225,7 @@ class ARrcStdEig {
   int GetIter();
   // Returns the actual number of Arnoldi iterations taken.
 
-  FLOAT GetTol() { return tol; }
+  ARFLOAT GetTol() { return tol; }
   // Returns the stopping criterion.
 
   int GetN() { return n; }
@@ -239,7 +240,7 @@ class ARrcStdEig {
   char* GetWhich() { return which; }
   // Returns "which".
 
-  TYPE GetShift() { return sigmaR; }
+  ARTYPE GetShift() { return sigmaR; }
   // Returns the shift (when in shift and invert mode).
 
   bool GetAutoShift() { return AutoShift; }
@@ -254,7 +255,7 @@ class ARrcStdEig {
   void ChangeMaxit(int maxitp);
   // Changes the maximum number of Arnoldi update iterations allowed.
 
-  void ChangeTol(FLOAT tolp);
+  void ChangeTol(ARFLOAT tolp);
   // Changes the stopping criterion.
 
   virtual void ChangeNev(int nevp);
@@ -266,7 +267,7 @@ class ARrcStdEig {
   virtual void ChangeWhich(char* whichp);
   // Changes "which".
 
-  virtual void ChangeShift(TYPE sigmaRp);
+  virtual void ChangeShift(ARTYPE sigmaRp);
   // Turns the problem to shift-and-invert mode with shift defined by sigmaRp.
   // Redefined in many derived classes.
 
@@ -280,7 +281,7 @@ class ARrcStdEig {
   virtual void SetRegularMode() { NoShift(); }
   // Turns problem to regular mode.
 
-  virtual void SetShiftInvertMode(TYPE sigmaRp) { ChangeShift(sigmaRp); }
+  virtual void SetShiftInvertMode(ARTYPE sigmaRp) { ChangeShift(sigmaRp); }
   // Turns problem to regular mode.
 
  // c.5) Trace functions.
@@ -315,17 +316,17 @@ class ARrcStdEig {
   //           vector x, and PutVector() indicates where to store y.
   // ido =  3: compute shifts, where PutVector() indicates where to store them.
 
-  virtual TYPE* GetVector();
+  virtual ARTYPE* GetVector();
   // When ido = -1, 1 or 2 and the user must perform a product in the form
   // y <- M*x, this function indicates where x is stored. When ido = 3, this
   // function indicates where the eigenvalues of the current Hessenberg
   // matrix are located.
 
-  TYPE* GetProd();
+  ARTYPE* GetProd();
   // When ido = 1 and the user must perform a product in the form
   // y <- M*B*x, this function indicates where B*x is stored.
 
-  virtual TYPE* PutVector();
+  virtual ARTYPE* PutVector();
   // When ido = -1, 1 or 2 and the user must perform a product in the form
   // y <- M*x, this function indicates where to store y. When ido = 3, this
   // function indicates where to store the shifts.
@@ -360,74 +361,74 @@ class ARrcStdEig {
 
  // c.8) Function that perform calculations using user supplied data structure.
 
-  virtual int Eigenvectors(TYPE* &EigVecp, bool ischur = false);
+  virtual int Eigenvectors(ARTYPE* &EigVecp, bool ischur = false);
   // Overrides array EigVecp sequentially with the eigenvectors of the
   // given eigen-problem. Also calculates Schur vectors if requested.
 
 
  // c.9) Functions that return elements of vectors and matrices.
 
-  TYPE ArnoldiBasisVector(int i, int j);
+  ARTYPE ArnoldiBasisVector(int i, int j);
   // Furnishes element j of the i-eth Arnoldi basis vector.
 
-  TYPE SchurVector(int i, int j);
+  ARTYPE SchurVector(int i, int j);
   // Furnishes element j of the i-eth Schur vector.
 
-  TYPE ResidualVector(int i);
+  ARTYPE ResidualVector(int i);
   // Furnishes element j of the residual vector.
 
 
  // c.10) Functions that provide raw access to internal vectors and matrices.
 
-  TYPE*  RawArnoldiBasisVectors();
+  ARTYPE* RawArnoldiBasisVectors();
   // Provides raw access to Arnoldi basis vectors elements.
 
-  TYPE*  RawArnoldiBasisVector(int i);
+  ARTYPE* RawArnoldiBasisVector(int i);
   // Provides raw access to Arnoldi basis vector i.
 
-  TYPE*  RawEigenvalues();
+  ARTYPE* RawEigenvalues();
   // Provides raw access to eigenvalues.
 
-  TYPE*  RawEigenvectors();
+  ARTYPE* RawEigenvectors();
   // Provides raw access to eigenvectors elements.
 
-  TYPE*  RawEigenvector(int i);
+  ARTYPE* RawEigenvector(int i);
   // Provides raw access to eigenvector i.
 
-  TYPE*  RawSchurVectors();
+  ARTYPE* RawSchurVectors();
   // Provides raw access to Schur vectors elements.
 
-  TYPE*  RawSchurVector(int i);
+  ARTYPE* RawSchurVector(int i);
   // Provides raw access to Schur vector i.
 
-  TYPE*  RawResidualVector();
+  ARTYPE* RawResidualVector();
   // Provides raw access to residual vector elements.
 
 
  // c.11) Functions that use STL vector class.
 
-#ifdef VECTOR_H
+#ifdef STL_VECTOR_H
 
-  vector<TYPE>* StlArnoldiBasisVectors();
+  vector<ARTYPE>* StlArnoldiBasisVectors();
   // Returns a copy of the Arnoldi basis in a single STL vector.
 
-  vector<TYPE>* StlArnoldiBasisVector(int i);
+  vector<ARTYPE>* StlArnoldiBasisVector(int i);
   // Returns the i-th Arnoldi basis vector in a STL vector.
 
-  vector<TYPE>* StlEigenvectors(bool ischur = false);
+  vector<ARTYPE>* StlEigenvectors(bool ischur = false);
   // Calculates the eigenvectors and stores them sequentially in a
   // single STL vector. Also calculates Schur vectors if requested.
 
-  vector<TYPE>* StlSchurVectors();
+  vector<ARTYPE>* StlSchurVectors();
   // Returns a copy of the Schur vectors in a single STL vector.
 
-  vector<TYPE>* StlSchurVector(int i);
+  vector<ARTYPE>* StlSchurVector(int i);
   // Returns the i-th Schur vector in a STL vector.
 
-  vector<TYPE>* StlResidualVector();
+  vector<ARTYPE>* StlResidualVector();
   // Returns the residual vector in a STL vector.
 
-#endif // #ifdef VECTOR_H.
+#endif // #ifdef STL_VECTOR_H.
 
 
  // c.12) Constructors and destructor.
@@ -454,8 +455,8 @@ class ARrcStdEig {
 // ------------------------------------------------------------------------ //
 
 
-template<class FLOAT, class TYPE>
-inline void ARrcStdEig<FLOAT, TYPE>::ClearFirst()
+template<class ARFLOAT, class ARTYPE>
+inline void ARrcStdEig<ARFLOAT, ARTYPE>::ClearFirst()
 {
 
   PrepareOK = newVal = newVec = newRes = false;
@@ -463,8 +464,8 @@ inline void ARrcStdEig<FLOAT, TYPE>::ClearFirst()
 } // ClearFirst.
 
 
-template<class FLOAT, class TYPE>
-inline void ARrcStdEig<FLOAT, TYPE>::ClearBasis()
+template<class ARFLOAT, class ARTYPE>
+inline void ARrcStdEig<ARFLOAT, ARTYPE>::ClearBasis()
 {
 
   BasisOK = ValuesOK = VectorsOK = SchurOK = false;
@@ -472,8 +473,8 @@ inline void ARrcStdEig<FLOAT, TYPE>::ClearBasis()
 } // ClearBasis.
 
 
-template<class FLOAT, class TYPE>
-void ARrcStdEig<FLOAT, TYPE>::ClearMem()
+template<class ARFLOAT, class ARTYPE>
+void ARrcStdEig<ARFLOAT, ARTYPE>::ClearMem()
 {
  
   // Deleting working arrays.
@@ -495,8 +496,8 @@ void ARrcStdEig<FLOAT, TYPE>::ClearMem()
   if (newRes) {
     delete[] resid;
     newRes = false;
+    resid = NULL;   // Salwen. Mar 3, 2000.
   }
-  resid = NULL;
 
   if (newVal) {
     delete[] EigValR;
@@ -519,24 +520,24 @@ void ARrcStdEig<FLOAT, TYPE>::ClearMem()
 } // ClearMem.
 
 
-template<class FLOAT, class TYPE>
-inline void ARrcStdEig<FLOAT, TYPE>::ValAllocate()
+template<class ARFLOAT, class ARTYPE>
+inline void ARrcStdEig<ARFLOAT, ARTYPE>::ValAllocate()
 {
 
   if (EigValR == NULL) {              // Creating a new array EigValR.
-    EigValR = new TYPE[ValSize()];
+    EigValR = new ARTYPE[ValSize()];
     newVal = true;
   }
 
 } // ValAllocate.
 
-template<class FLOAT, class TYPE>
-inline void ARrcStdEig<FLOAT, TYPE>::VecAllocate(bool newV)
+template<class ARFLOAT, class ARTYPE>
+inline void ARrcStdEig<ARFLOAT, ARTYPE>::VecAllocate(bool newV)
 {
 
   if (EigVec == NULL) {
     if (newV) {                       // Creating a new array EigVec.
-      EigVec = new TYPE[ValSize()*n];
+      EigVec = new ARTYPE[ValSize()*n];
       newVec = true;
     }
     else {                            // Using V to store EigVec.
@@ -547,8 +548,8 @@ inline void ARrcStdEig<FLOAT, TYPE>::VecAllocate(bool newV)
 } // VecAllocate.
 
 
-template<class FLOAT, class TYPE>
-void ARrcStdEig<FLOAT, TYPE>::WorkspaceAllocate()
+template<class ARFLOAT, class ARTYPE>
+void ARrcStdEig<ARFLOAT, ARTYPE>::WorkspaceAllocate()
 {
 
   lworkl = 0;
@@ -558,8 +559,8 @@ void ARrcStdEig<FLOAT, TYPE>::WorkspaceAllocate()
 } // WorkspaceAllocate.
 
 
-template<class FLOAT, class TYPE>
-void ARrcStdEig<FLOAT, TYPE>::AuppError()
+template<class ARFLOAT, class ARTYPE>
+void ARrcStdEig<ARFLOAT, ARTYPE>::AuppError()
 {
 
   switch (info) {
@@ -584,8 +585,8 @@ void ARrcStdEig<FLOAT, TYPE>::AuppError()
 } // AuppError.
 
 
-template<class FLOAT, class TYPE>
-void ARrcStdEig<FLOAT, TYPE>::EuppError()
+template<class ARFLOAT, class ARTYPE>
+void ARrcStdEig<ARFLOAT, ARTYPE>::EuppError()
 {
 
   switch (info) {
@@ -605,8 +606,8 @@ void ARrcStdEig<FLOAT, TYPE>::EuppError()
 } // EuppError.
 
 
-template<class FLOAT, class TYPE>
-inline int ARrcStdEig<FLOAT, TYPE>::CheckN(int np)
+template<class ARFLOAT, class ARTYPE>
+inline int ARrcStdEig<ARFLOAT, ARTYPE>::CheckN(int np)
 {
 
   if (np < 2) {
@@ -617,15 +618,15 @@ inline int ARrcStdEig<FLOAT, TYPE>::CheckN(int np)
 } // CheckN.
 
 
-template<class FLOAT, class TYPE>
-inline int ARrcStdEig<FLOAT, TYPE>::CheckNcv(int ncvp)
+template<class ARFLOAT, class ARTYPE>
+inline int ARrcStdEig<ARFLOAT, ARTYPE>::CheckNcv(int ncvp)
 {
 
   // Adjusting ncv if ncv <= nev or ncv > n.
 
   if (ncvp < nev+1) {
     if (ncvp) ArpackError::Set(ArpackError::NCV_OUT_OF_BOUNDS);
-    return 2*nev+1;
+    return ((2*nev+1)>n)?n:(2*nev+1);
   }
   else if (ncvp > n) {
     ArpackError::Set(ArpackError::NCV_OUT_OF_BOUNDS);
@@ -638,11 +639,11 @@ inline int ARrcStdEig<FLOAT, TYPE>::CheckNcv(int ncvp)
 } // CheckNcv.
 
 
-template<class FLOAT, class TYPE>
-inline int ARrcStdEig<FLOAT, TYPE>::CheckNev(int nevp)
+template<class ARFLOAT, class ARTYPE>
+inline int ARrcStdEig<ARFLOAT, ARTYPE>::CheckNev(int nevp)
 {
 
-  if ((nevp<=1)||(nevp>=n)) {
+  if ((nevp<1)||(nevp>=n)) { 
     throw ArpackError(ArpackError::NEV_OUT_OF_BOUNDS);
   }
   return nevp;
@@ -650,8 +651,8 @@ inline int ARrcStdEig<FLOAT, TYPE>::CheckNev(int nevp)
 } // CheckNev.
 
 
-template<class FLOAT, class TYPE>
-inline int ARrcStdEig<FLOAT, TYPE>::CheckMaxit(int maxitp)
+template<class ARFLOAT, class ARTYPE>
+inline int ARrcStdEig<ARFLOAT, ARTYPE>::CheckMaxit(int maxitp)
 {
 
   if (maxitp >= 1) return maxitp;
@@ -660,8 +661,8 @@ inline int ARrcStdEig<FLOAT, TYPE>::CheckMaxit(int maxitp)
 
 } // CheckMaxit.
 
-template<class FLOAT, class TYPE>
-char* ARrcStdEig<FLOAT, TYPE>::CheckWhich(char* whichp)
+template<class ARFLOAT, class ARTYPE>
+char* ARrcStdEig<ARFLOAT, ARTYPE>::CheckWhich(char* whichp)
 {
 
   switch (whichp[0]) {              // The first ought to be S or L.
@@ -680,8 +681,8 @@ char* ARrcStdEig<FLOAT, TYPE>::CheckWhich(char* whichp)
 } // CheckWhich.
 
 
-template<class FLOAT, class TYPE>
-void ARrcStdEig<FLOAT, TYPE>::Restart()
+template<class ARFLOAT, class ARTYPE>
+void ARrcStdEig<ARFLOAT, ARTYPE>::Restart()
 {
 
   nconv=0;                  // No eigenvalues found yet.
@@ -695,8 +696,8 @@ void ARrcStdEig<FLOAT, TYPE>::Restart()
 } // Restart.
 
 
-template<class FLOAT, class TYPE>
-void ARrcStdEig<FLOAT, TYPE>::Prepare()
+template<class ARFLOAT, class ARTYPE>
+void ARrcStdEig<ARFLOAT, ARTYPE>::Prepare()
 {
 
   // Deleting old stuff.
@@ -708,14 +709,14 @@ void ARrcStdEig<FLOAT, TYPE>::Prepare()
   try {
 
     if (resid == NULL) {       // Using a random starting vector.
-      resid  = new TYPE[n];
+      resid  = new ARTYPE[n];
       newRes = true;
     }
 
     // Setting dimensions of working arrays.
 
-    workd     = new TYPE[3*n+1];
-    V         = new TYPE[n*ncv+1];
+    workd    = new ARTYPE[3*n+1];
+    V        = new ARTYPE[n*ncv+1];
     WorkspaceAllocate();
 
   }
@@ -733,8 +734,8 @@ void ARrcStdEig<FLOAT, TYPE>::Prepare()
 } // Prepare.
 
 
-template<class FLOAT, class TYPE>
-void ARrcStdEig<FLOAT, TYPE>::Copy(const ARrcStdEig<FLOAT, TYPE>& other)
+template<class ARFLOAT, class ARTYPE>
+void ARrcStdEig<ARFLOAT,ARTYPE>::Copy(const ARrcStdEig<ARFLOAT,ARTYPE>& other)
 {
 
   // Defining local variables.
@@ -779,22 +780,22 @@ void ARrcStdEig<FLOAT, TYPE>::Copy(const ARrcStdEig<FLOAT, TYPE>& other)
 
   // Copying dynamic variables.
 
-  workd     = new TYPE[3*n+1];       // workd.
+  workd     = new ARTYPE[3*n+1];       // workd.
   copy(3*n+1,other.workd,1,workd,1);
 
-  V         = new TYPE[n*ncv+1];     // V.
+  V         = new ARTYPE[n*ncv+1];     // V.
   copy(n*ncv+1,other.V,1,V,1);
 
-  if (newRes) {                      // resid.
-    resid   = new TYPE[n];
+  if (newRes) {                        // resid.
+    resid   = new ARTYPE[n];
     copy(n,other.resid,1,resid,1);
   }
   else {
     resid   = other.resid;
   }
 
-  if (newVec) {                      // EigVec.
-    EigVec  = new TYPE[ValSize()*n];
+  if (newVec) {                        // EigVec.
+    EigVec  = new ARTYPE[ValSize()*n];
     copy(ValSize()*n,other.EigVec,1,EigVec,1);
   }
   else if (other.EigVec == (&other.V[1])) {
@@ -804,11 +805,11 @@ void ARrcStdEig<FLOAT, TYPE>::Copy(const ARrcStdEig<FLOAT, TYPE>& other)
     EigVec  = other.EigVec;
   }
 
-  if (newVal) {                      // EigValR and EigValI.
-    EigValR = new TYPE[ValSize()];
+  if (newVal) {                        // EigValR and EigValI.
+    EigValR = new ARTYPE[ValSize()];
     copy(ValSize(),other.EigValR,1,EigValR,1);
     if (other.EigValI != NULL) {
-      EigValI = new FLOAT[ValSize()];
+      EigValI = new ARFLOAT[ValSize()];
       copy(ValSize(),other.EigValI,1,EigValI,1);
     }
     else {
@@ -828,17 +829,17 @@ void ARrcStdEig<FLOAT, TYPE>::Copy(const ARrcStdEig<FLOAT, TYPE>& other)
 } // Copy.
 
 
-template<class FLOAT, class TYPE>
-void ARrcStdEig<FLOAT, TYPE>::
+template<class ARFLOAT, class ARTYPE>
+void ARrcStdEig<ARFLOAT, ARTYPE>::
 DefineParameters(int np, int nevp, char* whichp, int ncvp,
-                 FLOAT tolp, int maxitp, TYPE* residp, bool ishiftp)
+                 ARFLOAT tolp, int maxitp, ARTYPE* residp, bool ishiftp)
 
 {
 
   // Providing a "new" handler.
 
-  set_new_handler(MemoryOverflow);
-
+  std::set_new_handler(MemoryOverflow);
+  
   // Setting user defined parameters.
 
   try {
@@ -867,8 +868,8 @@ DefineParameters(int np, int nevp, char* whichp, int ncvp,
 } // DefineParameters.
 
 
-template<class FLOAT, class TYPE>
-int ARrcStdEig<FLOAT, TYPE>::GetIter()
+template<class ARFLOAT, class ARTYPE>
+int ARrcStdEig<ARFLOAT, ARTYPE>::GetIter()
 {
 
   if (BasisOK || ValuesOK || VectorsOK || SchurOK) {
@@ -881,8 +882,8 @@ int ARrcStdEig<FLOAT, TYPE>::GetIter()
 } // GetIter.
 
 
-template<class FLOAT, class TYPE>
-inline void ARrcStdEig<FLOAT, TYPE>::ChangeMaxit(int maxitp)
+template<class ARFLOAT, class ARTYPE>
+inline void ARrcStdEig<ARFLOAT, ARTYPE>::ChangeMaxit(int maxitp)
 {
 
   maxit = CheckMaxit(maxitp);
@@ -891,8 +892,8 @@ inline void ARrcStdEig<FLOAT, TYPE>::ChangeMaxit(int maxitp)
 } // ChangeMaxit.
 
 
-template<class FLOAT, class TYPE>
-inline void ARrcStdEig<FLOAT, TYPE>::ChangeTol(FLOAT tolp)
+template<class ARFLOAT, class ARTYPE>
+inline void ARrcStdEig<ARFLOAT, ARTYPE>::ChangeTol(ARFLOAT tolp)
 {
 
   if (tolp < tol) Restart();
@@ -901,8 +902,8 @@ inline void ARrcStdEig<FLOAT, TYPE>::ChangeTol(FLOAT tolp)
 } // ChangeTol.
 
 
-template<class FLOAT, class TYPE>
-void ARrcStdEig<FLOAT, TYPE>::ChangeNev(int nevp)
+template<class ARFLOAT, class ARTYPE>
+void ARrcStdEig<ARFLOAT, ARTYPE>::ChangeNev(int nevp)
 {
 
   try { 
@@ -915,8 +916,8 @@ void ARrcStdEig<FLOAT, TYPE>::ChangeNev(int nevp)
 } // ChangeNev.
 
 
-template<class FLOAT, class TYPE>
-inline void ARrcStdEig<FLOAT, TYPE>::ChangeNcv(int ncvp)
+template<class ARFLOAT, class ARTYPE>
+inline void ARrcStdEig<ARFLOAT, ARTYPE>::ChangeNcv(int ncvp)
 {
 
   ncv = CheckNcv(ncvp);
@@ -925,8 +926,8 @@ inline void ARrcStdEig<FLOAT, TYPE>::ChangeNcv(int ncvp)
 } // ChangeNcv.
 
 
-template<class FLOAT, class TYPE>
-void ARrcStdEig<FLOAT, TYPE>::ChangeWhich(char* whichp)
+template<class ARFLOAT, class ARTYPE>
+void ARrcStdEig<ARFLOAT, ARTYPE>::ChangeWhich(char* whichp)
 {
 
   try { which = CheckWhich(whichp); }
@@ -936,8 +937,8 @@ void ARrcStdEig<FLOAT, TYPE>::ChangeWhich(char* whichp)
 } // ChangeWhich.
 
 
-template<class FLOAT, class TYPE>
-inline void ARrcStdEig<FLOAT, TYPE>::ChangeShift(TYPE sigmaRp)
+template<class ARFLOAT, class ARTYPE>
+inline void ARrcStdEig<ARFLOAT, ARTYPE>::ChangeShift(ARTYPE sigmaRp)
 {
 
   sigmaR    = sigmaRp;
@@ -949,11 +950,11 @@ inline void ARrcStdEig<FLOAT, TYPE>::ChangeShift(TYPE sigmaRp)
 } // ChangeShift.
 
 
-template<class FLOAT, class TYPE>
-inline void ARrcStdEig<FLOAT, TYPE>::NoShift()
+template<class ARFLOAT, class ARTYPE>
+inline void ARrcStdEig<ARFLOAT, ARTYPE>::NoShift()
 {
 
-  sigmaR    = (TYPE)0;
+  sigmaR    = (ARTYPE)0;
   sigmaI    = 0.0;
   mode      = 1;
   iparam[7] = mode;
@@ -962,8 +963,8 @@ inline void ARrcStdEig<FLOAT, TYPE>::NoShift()
 } // NoShift.
 
 
-template<class FLOAT, class TYPE>
-void ARrcStdEig<FLOAT, TYPE>::InvertAutoShift()
+template<class ARFLOAT, class ARTYPE>
+void ARrcStdEig<ARFLOAT, ARTYPE>::InvertAutoShift()
 {
 
   AutoShift = !AutoShift;
@@ -972,8 +973,8 @@ void ARrcStdEig<FLOAT, TYPE>::InvertAutoShift()
 } // InvertAutoShift.
 
 
-template<class FLOAT, class TYPE>
-TYPE* ARrcStdEig<FLOAT, TYPE>::GetVector()
+template<class ARFLOAT, class ARTYPE>
+ARTYPE* ARrcStdEig<ARFLOAT, ARTYPE>::GetVector()
 {
 
   switch (ido) {
@@ -990,8 +991,8 @@ TYPE* ARrcStdEig<FLOAT, TYPE>::GetVector()
 } // GetVector.
 
 
-template<class FLOAT, class TYPE>
-TYPE* ARrcStdEig<FLOAT, TYPE>::GetProd()
+template<class ARFLOAT, class ARTYPE>
+ARTYPE* ARrcStdEig<ARFLOAT, ARTYPE>::GetProd()
 {
 
   if (ido != 1) {
@@ -1002,8 +1003,8 @@ TYPE* ARrcStdEig<FLOAT, TYPE>::GetProd()
 } // GetProd.
 
 
-template<class FLOAT, class TYPE>
-TYPE* ARrcStdEig<FLOAT, TYPE>::PutVector()
+template<class ARFLOAT, class ARTYPE>
+ARTYPE* ARrcStdEig<ARFLOAT, ARTYPE>::PutVector()
 {
 
   switch (ido) {
@@ -1020,8 +1021,8 @@ TYPE* ARrcStdEig<FLOAT, TYPE>::PutVector()
 } // PutVector.
 
 
-template<class FLOAT, class TYPE>
-int ARrcStdEig<FLOAT, TYPE>::TakeStep()
+template<class ARFLOAT, class ARTYPE>
+int ARrcStdEig<ARFLOAT, ARTYPE>::TakeStep()
 {
 
   // Requiring the definition of all internal variables.
@@ -1051,8 +1052,8 @@ int ARrcStdEig<FLOAT, TYPE>::TakeStep()
 } // TakeStep.
 
 
-template<class FLOAT, class TYPE>
-inline int ARrcStdEig<FLOAT, TYPE>::FindArnoldiBasis()
+template<class ARFLOAT, class ARTYPE>
+inline int ARrcStdEig<ARFLOAT, ARTYPE>::FindArnoldiBasis()
 {
 
   if (!BasisOK) {
@@ -1063,8 +1064,8 @@ inline int ARrcStdEig<FLOAT, TYPE>::FindArnoldiBasis()
 } // FindArnoldiBasis.
 
 
-template<class FLOAT, class TYPE>
-int ARrcStdEig<FLOAT, TYPE>::FindEigenvalues()
+template<class ARFLOAT, class ARTYPE>
+int ARrcStdEig<ARFLOAT, ARTYPE>::FindEigenvalues()
 {
 
   // Determining eigenvalues if they are not available.
@@ -1090,8 +1091,8 @@ int ARrcStdEig<FLOAT, TYPE>::FindEigenvalues()
 } // FindEigenvalues.
 
 
-template<class FLOAT, class TYPE>
-int ARrcStdEig<FLOAT, TYPE>::FindEigenvectors(bool schurp)
+template<class ARFLOAT, class ARTYPE>
+int ARrcStdEig<ARFLOAT, ARTYPE>::FindEigenvectors(bool schurp)
 {
 
   // Determining eigenvectors if they are not available.
@@ -1122,8 +1123,8 @@ int ARrcStdEig<FLOAT, TYPE>::FindEigenvectors(bool schurp)
 } // FindEigenvectors.
 
 
-template<class FLOAT, class TYPE>
-int ARrcStdEig<FLOAT, TYPE>::FindSchurVectors()
+template<class ARFLOAT, class ARTYPE>
+int ARrcStdEig<ARFLOAT, ARTYPE>::FindSchurVectors()
 {
 
   // Determining Schur vectors if they are not available.
@@ -1152,9 +1153,9 @@ int ARrcStdEig<FLOAT, TYPE>::FindSchurVectors()
 } // FindSchurVectors.
 
 
-template<class FLOAT, class TYPE>
-int ARrcStdEig<FLOAT, TYPE>::
-Eigenvectors(TYPE* &EigVecp, bool ischur = false)
+template<class ARFLOAT, class ARTYPE>
+int ARrcStdEig<ARFLOAT, ARTYPE>::
+Eigenvectors(ARTYPE* &EigVecp, bool ischur)
 {
 
   // Overriding EigVecp with the converged eigenvectors.
@@ -1168,7 +1169,7 @@ Eigenvectors(TYPE* &EigVecp, bool ischur = false)
     }
     else {                               // Copying eigenvectors.
       if (EigVecp == NULL) {
-        try { EigVecp = new TYPE[ValSize()*n]; }
+        try { EigVecp = new ARTYPE[ValSize()*n]; }
         catch (ArpackError) { return 0; }
       }
       copy(ValSize()*n,EigVec,1,EigVecp,1);
@@ -1180,7 +1181,7 @@ Eigenvectors(TYPE* &EigVecp, bool ischur = false)
       newVec = false;
     }
     if (EigVecp == NULL) {
-      try { EigVecp = new TYPE[ValSize()*n]; }
+      try { EigVecp = new ARTYPE[ValSize()*n]; }
       catch (ArpackError) { return 0; }
     }
     EigVec = EigVecp;
@@ -1192,8 +1193,8 @@ Eigenvectors(TYPE* &EigVecp, bool ischur = false)
 } // Eigenvectors(EigVecp, ischur).
 
 
-template<class FLOAT, class TYPE>
-inline TYPE ARrcStdEig<FLOAT, TYPE>::ArnoldiBasisVector(int i, int j)
+template<class ARFLOAT, class ARTYPE>
+inline ARTYPE ARrcStdEig<ARFLOAT, ARTYPE>::ArnoldiBasisVector(int i, int j)
 {
 
   // Returning element j of Arnoldi basis vector i.
@@ -1209,8 +1210,8 @@ inline TYPE ARrcStdEig<FLOAT, TYPE>::ArnoldiBasisVector(int i, int j)
 } // ArnoldiBasisVector(i,j).
 
 
-template<class FLOAT, class TYPE>
-inline TYPE ARrcStdEig<FLOAT, TYPE>::SchurVector(int i, int j)
+template<class ARFLOAT, class ARTYPE>
+inline ARTYPE ARrcStdEig<ARFLOAT, ARTYPE>::SchurVector(int i, int j)
 {
 
   // Returning element j of Schur vector i.
@@ -1226,8 +1227,8 @@ inline TYPE ARrcStdEig<FLOAT, TYPE>::SchurVector(int i, int j)
 } // SchurVector(i,j).
 
 
-template<class FLOAT, class TYPE>
-inline TYPE ARrcStdEig<FLOAT, TYPE>::ResidualVector(int i)
+template<class ARFLOAT, class ARTYPE>
+inline ARTYPE ARrcStdEig<ARFLOAT, ARTYPE>::ResidualVector(int i)
 {
 
   // Returning element i of the residual vector.
@@ -1243,8 +1244,8 @@ inline TYPE ARrcStdEig<FLOAT, TYPE>::ResidualVector(int i)
 } // ResidualVector(i).
 
 
-template<class FLOAT, class TYPE>
-inline TYPE* ARrcStdEig<FLOAT, TYPE>::RawArnoldiBasisVectors()
+template<class ARFLOAT, class ARTYPE>
+inline ARTYPE* ARrcStdEig<ARFLOAT, ARTYPE>::RawArnoldiBasisVectors()
 {
 
   // Returning a constant pointer to Arnoldi basis.
@@ -1257,8 +1258,8 @@ inline TYPE* ARrcStdEig<FLOAT, TYPE>::RawArnoldiBasisVectors()
 } // RawArnoldiBasisVectors.
 
 
-template<class FLOAT, class TYPE>
-inline TYPE* ARrcStdEig<FLOAT, TYPE>::RawArnoldiBasisVector(int i)
+template<class ARFLOAT, class ARTYPE>
+inline ARTYPE* ARrcStdEig<ARFLOAT, ARTYPE>::RawArnoldiBasisVector(int i)
 {
 
   // Returning a constant pointer to Arnoldi basis vector i.
@@ -1274,8 +1275,8 @@ inline TYPE* ARrcStdEig<FLOAT, TYPE>::RawArnoldiBasisVector(int i)
 } // RawArnoldiBasisVector(i).
 
 
-template<class FLOAT, class TYPE>
-inline TYPE* ARrcStdEig<FLOAT, TYPE>::RawEigenvalues()
+template<class ARFLOAT, class ARTYPE>
+inline ARTYPE* ARrcStdEig<ARFLOAT, ARTYPE>::RawEigenvalues()
 {
 
   if (!ValuesOK) {
@@ -1286,8 +1287,8 @@ inline TYPE* ARrcStdEig<FLOAT, TYPE>::RawEigenvalues()
 } // RawEigenvalues.
 
 
-template<class FLOAT, class TYPE>
-inline TYPE* ARrcStdEig<FLOAT, TYPE>::RawEigenvectors()
+template<class ARFLOAT, class ARTYPE>
+inline ARTYPE* ARrcStdEig<ARFLOAT, ARTYPE>::RawEigenvectors()
 {
 
   if (!VectorsOK) {
@@ -1298,8 +1299,8 @@ inline TYPE* ARrcStdEig<FLOAT, TYPE>::RawEigenvectors()
 } // RawEigenvectors.
 
 
-template<class FLOAT, class TYPE>
-inline TYPE* ARrcStdEig<FLOAT, TYPE>::RawEigenvector(int i)
+template<class ARFLOAT, class ARTYPE>
+inline ARTYPE* ARrcStdEig<ARFLOAT, ARTYPE>::RawEigenvector(int i)
 {
 
   // Returning a constant pointer to eigenvector i.
@@ -1315,8 +1316,8 @@ inline TYPE* ARrcStdEig<FLOAT, TYPE>::RawEigenvector(int i)
 } // RawEigenvector(i).
 
 
-template<class FLOAT, class TYPE>
-inline TYPE* ARrcStdEig<FLOAT, TYPE>::RawSchurVectors()
+template<class ARFLOAT, class ARTYPE>
+inline ARTYPE* ARrcStdEig<ARFLOAT, ARTYPE>::RawSchurVectors()
 {
 
   if (!SchurOK) {
@@ -1327,8 +1328,8 @@ inline TYPE* ARrcStdEig<FLOAT, TYPE>::RawSchurVectors()
 } // RawSchurVectors.
 
 
-template<class FLOAT, class TYPE>
-inline TYPE* ARrcStdEig<FLOAT, TYPE>::RawSchurVector(int i)
+template<class ARFLOAT, class ARTYPE>
+inline ARTYPE* ARrcStdEig<ARFLOAT, ARTYPE>::RawSchurVector(int i)
 {
 
   // Returning a constant pointer to Schur vector i.
@@ -1344,8 +1345,8 @@ inline TYPE* ARrcStdEig<FLOAT, TYPE>::RawSchurVector(int i)
 } // RawSchurVector(i).
 
 
-template<class FLOAT, class TYPE>
-inline TYPE* ARrcStdEig<FLOAT, TYPE>::RawResidualVector()
+template<class ARFLOAT, class ARTYPE>
+inline ARTYPE* ARrcStdEig<ARFLOAT, ARTYPE>::RawResidualVector()
 {
 
   if (!newRes) {
@@ -1356,21 +1357,21 @@ inline TYPE* ARrcStdEig<FLOAT, TYPE>::RawResidualVector()
 } // RawResidualVector.
 
 
-#ifdef VECTOR_H // Defining some functions that use STL vector class.
+#ifdef STL_VECTOR_H // Defining some functions that use STL vector class.
 
-template<class FLOAT, class TYPE>
-inline vector<TYPE>* ARrcStdEig<FLOAT, TYPE>::StlArnoldiBasisVectors()
+template<class ARFLOAT, class ARTYPE>
+inline vector<ARTYPE>* ARrcStdEig<ARFLOAT, ARTYPE>::StlArnoldiBasisVectors()
 {
 
   // Returning the Arnoldi basis in a single STL vector.
 
-  vector<TYPE>* StlBasis;
+  vector<ARTYPE>* StlBasis;
 
   if (!BasisOK) {
     nconv = FindArnoldiBasis();
   }
   try {
-    StlBasis = new vector<TYPE>(&V[1], &V[n*ncv+1]);
+    StlBasis = new vector<ARTYPE>(&V[1], &V[n*ncv+1]);
   }
   catch (ArpackError) { return NULL; }
   return StlBasis;
@@ -1378,13 +1379,13 @@ inline vector<TYPE>* ARrcStdEig<FLOAT, TYPE>::StlArnoldiBasisVectors()
 } // StlArnoldiBasisVectors.
 
 
-template<class FLOAT, class TYPE>
-inline vector<TYPE>* ARrcStdEig<FLOAT, TYPE>::StlArnoldiBasisVector(int i)
+template<class ARFLOAT, class ARTYPE>
+inline vector<ARTYPE>* ARrcStdEig<ARFLOAT,ARTYPE>::StlArnoldiBasisVector(int i)
 {
 
   // Returning the i-th Arnoldi basis vector in a STL vector.
 
-  vector<TYPE>* StlBasis;
+  vector<ARTYPE>* StlBasis;
 
   if (!BasisOK) {
     throw ArpackError(ArpackError::BASIS_NOT_OK, "StlArnoldiBasisVector(i)");
@@ -1393,7 +1394,7 @@ inline vector<TYPE>* ARrcStdEig<FLOAT, TYPE>::StlArnoldiBasisVector(int i)
     throw ArpackError(ArpackError::RANGE_ERROR,"StlArnoldiBasisVector(i)");
   }
   try {
-    StlBasis = new vector<TYPE>(&V[i*n+1], &V[(i+1)*n+1]);
+    StlBasis = new vector<ARTYPE>(&V[i*n+1], &V[(i+1)*n+1]);
   }
   catch (ArpackError) { return NULL; }
   return StlBasis;
@@ -1401,16 +1402,16 @@ inline vector<TYPE>* ARrcStdEig<FLOAT, TYPE>::StlArnoldiBasisVector(int i)
 } // StlArnoldiBasisVector(i).
 
 
-template<class FLOAT, class TYPE>
-inline vector<TYPE>* ARrcStdEig<FLOAT, TYPE>::StlEigenvectors(bool ischur)
+template<class ARFLOAT, class ARTYPE>
+inline vector<ARTYPE>* ARrcStdEig<ARFLOAT,ARTYPE>::StlEigenvectors(bool ischur)
 {
 
   // Returning the eigenvector in a single STL vector.
 
-  vector<TYPE>* StlEigVec;
-  TYPE*         VecPtr;
+  vector<ARTYPE>* StlEigVec;
+  ARTYPE*         VecPtr;
 
-  try { StlEigVec = new vector<TYPE>(ValSize()*n); }
+  try { StlEigVec = new vector<ARTYPE>(ValSize()*n); }
   catch (ArpackError) { return NULL; }
   VecPtr = StlEigVec->begin();
   nconv  = Eigenvectors(VecPtr, ischur);
@@ -1419,17 +1420,17 @@ inline vector<TYPE>* ARrcStdEig<FLOAT, TYPE>::StlEigenvectors(bool ischur)
 } // StlEigenvectors.
 
 
-template<class FLOAT, class TYPE>
-inline vector<TYPE>* ARrcStdEig<FLOAT, TYPE>::StlSchurVectors()
+template<class ARFLOAT, class ARTYPE>
+inline vector<ARTYPE>* ARrcStdEig<ARFLOAT, ARTYPE>::StlSchurVectors()
 {
 
-  vector<TYPE>* StlSchurVec;
+  vector<ARTYPE>* StlSchurVec;
 
   if (!SchurOK) {
     nconv = FindSchurVectors();
   } 
   try {
-    StlSchurVec = new vector<TYPE>(&V[1], &V[nev*n+1]);
+    StlSchurVec = new vector<ARTYPE>(&V[1], &V[nev*n+1]);
   }
   catch (ArpackError) { return NULL; }
   return StlSchurVec;
@@ -1437,13 +1438,13 @@ inline vector<TYPE>* ARrcStdEig<FLOAT, TYPE>::StlSchurVectors()
 } // StlSchurVectors.
 
 
-template<class FLOAT, class TYPE>
-inline vector<TYPE>* ARrcStdEig<FLOAT, TYPE>::StlSchurVector(int i)
+template<class ARFLOAT, class ARTYPE>
+inline vector<ARTYPE>* ARrcStdEig<ARFLOAT, ARTYPE>::StlSchurVector(int i)
 {
 
   // Returning the i-th Schur vector in a STL vector.
 
-  vector<TYPE>* StlSchurVec;
+  vector<ARTYPE>* StlSchurVec;
 
   if (!SchurOK) {
     throw ArpackError(ArpackError::SCHUR_NOT_OK, "StlSchurVector(i)");
@@ -1452,7 +1453,7 @@ inline vector<TYPE>* ARrcStdEig<FLOAT, TYPE>::StlSchurVector(int i)
     throw ArpackError(ArpackError::RANGE_ERROR, "StlSchurVector(i)");
   }
   try {
-    StlSchurVec = new vector<TYPE>(&V[i*n+1], &V[(i+1)*n+1]);
+    StlSchurVec = new vector<ARTYPE>(&V[i*n+1], &V[(i+1)*n+1]);
   }
   catch (ArpackError) { return NULL; }
   return StlSchurVec;
@@ -1460,30 +1461,30 @@ inline vector<TYPE>* ARrcStdEig<FLOAT, TYPE>::StlSchurVector(int i)
 } // StlSchurVector(i).
 
 
-template<class FLOAT, class TYPE>
-inline vector<TYPE>* ARrcStdEig<FLOAT, TYPE>::StlResidualVector()
+template<class ARFLOAT, class ARTYPE>
+inline vector<ARTYPE>* ARrcStdEig<ARFLOAT, ARTYPE>::StlResidualVector()
 {
 
   // Returning the residual vector in a STL vector.
 
-  vector<TYPE>* StlResid;
+  vector<ARTYPE>* StlResid;
 
   if (!newRes) {
     throw ArpackError(ArpackError::RESID_NOT_OK, "StlResidualVector");
   }
   try {
-    StlResid = new vector<TYPE>(resid, &resid[n]);
+    StlResid = new vector<ARTYPE>(resid, &resid[n]);
   }
   catch (ArpackError) { return NULL; }
   return StlResid;
 
 } // StlResidualVector.
 
-#endif // #ifdef VECTOR_H.
+#endif // #ifdef STL_VECTOR_H.
 
 
-template<class FLOAT, class TYPE>
-inline ARrcStdEig<FLOAT, TYPE>::ARrcStdEig()
+template<class ARFLOAT, class ARTYPE>
+inline ARrcStdEig<ARFLOAT, ARTYPE>::ARrcStdEig()
 {
 
   resid   = NULL;
@@ -1503,9 +1504,9 @@ inline ARrcStdEig<FLOAT, TYPE>::ARrcStdEig()
 } // Short constructor.
 
 
-template<class FLOAT, class TYPE>
-ARrcStdEig<FLOAT, TYPE>& ARrcStdEig<FLOAT, TYPE>::
-operator=(const ARrcStdEig<FLOAT, TYPE>& other)
+template<class ARFLOAT, class ARTYPE>
+ARrcStdEig<ARFLOAT, ARTYPE>& ARrcStdEig<ARFLOAT, ARTYPE>::
+operator=(const ARrcStdEig<ARFLOAT, ARTYPE>& other)
 {
 
   if (this != &other) { // Stroustrup suggestion.
