@@ -1,5 +1,5 @@
 /*
-   ARPACK++ v1.0 8/1/1997
+   ARPACK++ v1.2 2/20/2000
    c++ interface to ARPACK code.
 
    MODULE ARRSNSym.h.
@@ -26,8 +26,8 @@
 #include "neupp.h"
 
 
-template<class FLOAT>
-class ARrcNonSymStdEig: public virtual ARrcStdEig<FLOAT, FLOAT> {
+template<class ARFLOAT>
+class ARrcNonSymStdEig: public virtual ARrcStdEig<ARFLOAT, ARFLOAT> {
 
  protected:
 
@@ -35,7 +35,7 @@ class ARrcNonSymStdEig: public virtual ARrcStdEig<FLOAT, FLOAT> {
 
  // a.1) Memory control functions.
 
-  int ValSize() { return nev+1; }
+  int ValSize() { return this->nev+1; }
   // Provides the size of array EigVal.
 
   void ValAllocate();
@@ -67,25 +67,26 @@ class ARrcNonSymStdEig: public virtual ARrcStdEig<FLOAT, FLOAT> {
   // a complex conjugate pair.
 
 #ifdef ARCOMP_H
-#ifdef VECTOR_H
+#ifdef STL_VECTOR_H
 
-  vector<arcomplex<FLOAT> >* GenComplex(vector<FLOAT>* RealPart, 
-                                        vector<FLOAT>* ImagPart, 
-                                        bool conj = false);
+  vector<arcomplex<ARFLOAT> >* GenComplex(vector<ARFLOAT>* RealPart, 
+                                          vector<ARFLOAT>* ImagPart, 
+                                          bool conj = false);
   // Generates a complex vector Complex = RealPart + I*ImagPart
   // (or Complex = RealPart - I*ImagPart, if conj = true).
 
-  vector<arcomplex<FLOAT> >* GenComplex(int dim, FLOAT* RealPart, 
-                                        FLOAT* ImagPart, bool conj = false);
+  vector<arcomplex<ARFLOAT> >* GenComplex(int dim, ARFLOAT* RealPart, 
+                                          ARFLOAT* ImagPart, 
+                                          bool conj = false);
   // Generates a complex vector Complex = RealPart + I*ImagPart
   // (or Complex = RealPart - I*ImagPart, if conj = true). dim
   // is the length of RealPart and ImagPart.
 
-  vector<arcomplex<FLOAT> >* GenComplex(int dim, FLOAT* RealPart);
+  vector<arcomplex<ARFLOAT> >* GenComplex(int dim, ARFLOAT* RealPart);
   // Generates a complex vector from a real vector. dim is the
   // length of RealPart.
 
-#endif // VECTOR_H.
+#endif // STL_VECTOR_H.
 #endif // ARCOMP_H.
 
  public:
@@ -105,21 +106,21 @@ class ARrcNonSymStdEig: public virtual ARrcStdEig<FLOAT, FLOAT> {
 
  // b.2) Functions that permit step by step execution of ARPACK.
 
-  FLOAT* GetVectorImag();
+  ARFLOAT* GetVectorImag();
   // When ido = 3, this function indicates where the imaginary part
   // of the eigenvalues of the current Hessenberg matrix are located.
 
 
  // b.3) Functions that perform all calculations in one step.
 
-  int Eigenvalues(FLOAT* &EigValRp, FLOAT* &EigValIp,
-                   bool ivec = false, bool ischur = false);
+  int Eigenvalues(ARFLOAT* &EigValRp, ARFLOAT* &EigValIp,
+                  bool ivec = false, bool ischur = false);
   // Overrides arrays EigValRp with the real part and EigValIp 
   // with the imaginary part of the eigenvalues of the problem. 
   // Calculates eigenvectors and Schur vectors if requested.
 
-  int EigenValVectors(FLOAT* &EigVecp, FLOAT* &EigValRp, FLOAT* &EigValIp,
-                       bool ischur = false);
+  int EigenValVectors(ARFLOAT* &EigVecp, ARFLOAT* &EigValRp, 
+                      ARFLOAT* &EigValIp, bool ischur = false);
   // Overrides array EigVecp sequentially with the eigenvectors of the
   // given eigen-problem. Also stores the eigenvalues in EigValRp and
   // EigValIp. Calculates Schur vectors if requested.
@@ -128,63 +129,63 @@ class ARrcNonSymStdEig: public virtual ARrcStdEig<FLOAT, FLOAT> {
  // b.4) Functions that return elements of vectors and matrices.
 
 #ifdef ARCOMP_H
-  arcomplex<FLOAT> Eigenvalue(int i);
+  arcomplex<ARFLOAT> Eigenvalue(int i);
   // Furnishes i-eth eigenvalue.
 #endif // ARCOMP_H.
 
-  FLOAT EigenvalueReal(int i);
+  ARFLOAT EigenvalueReal(int i);
   // Provides the real part of the i-eth eigenvalue.
 
-  FLOAT EigenvalueImag(int i);
+  ARFLOAT EigenvalueImag(int i);
   // Provides the imaginary part of the i-eth eigenvalue.
 
 #ifdef ARCOMP_H
-  arcomplex<FLOAT> Eigenvector(int i, int j);
+  arcomplex<ARFLOAT> Eigenvector(int i, int j);
   // Furnishes element j of the i-eth eigenvector.
 #endif // ARCOMP_H.
 
-  FLOAT EigenvectorReal(int i, int j);
+  ARFLOAT EigenvectorReal(int i, int j);
   // Provides the real part of element j of the i-eth eigenvector.
 
-  FLOAT EigenvectorImag(int i, int j);
+  ARFLOAT EigenvectorImag(int i, int j);
   // Provides the imaginary part of element j of the i-eth eigenvector.
 
 
  // b.5) Functions that provide raw access to internal vectors and matrices.
 
-  FLOAT* RawEigenvaluesImag();
+  ARFLOAT* RawEigenvaluesImag();
   // Provides raw access to the imaginary part of eigenvalues.
 
 
  // b.6) Functions that use STL vector class.
 
-#ifdef VECTOR_H
+#ifdef STL_VECTOR_H
 
 #ifdef ARCOMP_H
-  vector<arcomplex<FLOAT> >* StlEigenvalues(bool ivec = false, 
-                                            bool ischur = false);
+  vector<arcomplex<ARFLOAT> >* StlEigenvalues(bool ivec = false, 
+                                              bool ischur = false);
   // Calculates the eigenvalues and stores them in a single STL vector.
   // Also calculates eigenvectors and Schur vectors if requested.
 #endif // ARCOMP_H.
 
-  vector<FLOAT>* StlEigenvaluesReal();
+  vector<ARFLOAT>* StlEigenvaluesReal();
   // Returns the real part of the eigenvalues.
 
-  vector<FLOAT>* StlEigenvaluesImag();
+  vector<ARFLOAT>* StlEigenvaluesImag();
   // Returns the imaginary part of the eigenvalues.
 
 #ifdef ARCOMP_H
-  vector<arcomplex<FLOAT> >* StlEigenvector(int i);
+  vector<arcomplex<ARFLOAT> >* StlEigenvector(int i);
   // Returns the i-th eigenvector.
 #endif // ARCOMP_H.
 
-  vector<FLOAT>* StlEigenvectorReal(int i);
+  vector<ARFLOAT>* StlEigenvectorReal(int i);
   // Returns the real part of the i-th eigenvector.
 
-  vector<FLOAT>* StlEigenvectorImag(int i);
+  vector<ARFLOAT>* StlEigenvectorImag(int i);
   // Returns the imaginary part of the i-th eigenvector.
 
-#endif // VECTOR_H.
+#endif // STL_VECTOR_H.
 
 
  // b.7) Constructors and destructor.
@@ -193,13 +194,13 @@ class ARrcNonSymStdEig: public virtual ARrcStdEig<FLOAT, FLOAT> {
   // Short constructor.
 
   ARrcNonSymStdEig(int np, int nevp, char* whichp = "LM", int ncvp = 0,
-                   FLOAT tolp = 0.0, int maxitp = 0, FLOAT* residp = NULL,
+                   ARFLOAT tolp = 0.0, int maxitp = 0, ARFLOAT* residp = NULL,
                    bool ishiftp = true);
   // Long constructor (regular mode).
 
-  ARrcNonSymStdEig(int np, int nevp, FLOAT sigma, char* whichp = "LM",
-                   int ncvp = 0, FLOAT tolp = 0.0, int maxitp = 0,
-                   FLOAT* residp = NULL, bool ishiftp = true);
+  ARrcNonSymStdEig(int np, int nevp, ARFLOAT sigma, char* whichp = "LM",
+                   int ncvp = 0, ARFLOAT tolp = 0.0, int maxitp = 0,
+                   ARFLOAT* residp = NULL, bool ishiftp = true);
   // Long constructor (shift and invert mode).
 
   ARrcNonSymStdEig(const ARrcNonSymStdEig& other) { Copy(other); }
@@ -221,58 +222,58 @@ class ARrcNonSymStdEig: public virtual ARrcStdEig<FLOAT, FLOAT> {
 // ------------------------------------------------------------------------ //
 
 
-template<class FLOAT>
-inline void ARrcNonSymStdEig<FLOAT>::ValAllocate()
+template<class ARFLOAT>
+inline void ARrcNonSymStdEig<ARFLOAT>::ValAllocate()
 {
 
-  if (EigValR == NULL) {
-    EigValR = new FLOAT[ValSize()];
-    EigValI = new FLOAT[ValSize()];
-    newVal = true;
+  if (this->EigValR == NULL) {
+    this->EigValR = new ARFLOAT[ValSize()];
+    this->EigValI = new ARFLOAT[ValSize()];
+    this->newVal = true;
   }
 
 } // ValAllocate.
 
 
-template<class FLOAT>
-inline void ARrcNonSymStdEig<FLOAT>::WorkspaceAllocate()
+template<class ARFLOAT>
+inline void ARrcNonSymStdEig<ARFLOAT>::WorkspaceAllocate()
 {
 
-  lworkl  = 3*ncv*(ncv+2);
-  lworkv  = 3*ncv;
-  lrwork  = 0;
-  workl   = new FLOAT[lworkl+1];
-  workv   = new FLOAT[lworkv+1];
+  this->lworkl  = 3*this->ncv*(this->ncv+2);
+  this->lworkv  = 3*this->ncv;
+  this->lrwork  = 0;
+  this->workl   = new ARFLOAT[this->lworkl+1];
+  this->workv   = new ARFLOAT[this->lworkv+1];
 
 } // WorkspaceAllocate.
 
 
-template<class FLOAT>
-inline void ARrcNonSymStdEig<FLOAT>::Aupp()
+template<class ARFLOAT>
+inline void ARrcNonSymStdEig<ARFLOAT>::Aupp()
 {
 
-  naupp(ido, bmat, n, which, nev, tol, resid, ncv, V, n,
-        iparam, ipntr, workd, workl, lworkl, info);
+  naupp(this->ido, this->bmat, this->n, this->which, this->nev, this->tol, this->resid, this->ncv, this->V, this->n,
+        this->iparam, this->ipntr, this->workd, this->workl, this->lworkl, this->info);
 
 } // Aupp.
 
 
-template<class FLOAT>
-inline void ARrcNonSymStdEig<FLOAT>::Eupp()
+template<class ARFLOAT>
+inline void ARrcNonSymStdEig<ARFLOAT>::Eupp()
 {
 
-  neupp(rvec, HowMny, EigValR, EigValI, EigVec, n, sigmaR,
-        sigmaI, workv, bmat, n, which, nev, tol, resid, ncv, V,
-        n, iparam, ipntr, workd, workl, lworkl, info);
+  neupp(this->rvec, this->HowMny, this->EigValR, this->EigValI, this->EigVec, this->n, this->sigmaR,
+        this->sigmaI, this->workv, this->bmat, this->n, this->which, this->nev, this->tol, this->resid, this->ncv, this->V,
+        this->n, this->iparam, this->ipntr, this->workd, this->workl, this->lworkl, this->info);
 
 } // Eupp.
 
 
-template<class FLOAT>
-inline int ARrcNonSymStdEig<FLOAT>::CheckNev(int nevp)
+template<class ARFLOAT>
+inline int ARrcNonSymStdEig<ARFLOAT>::CheckNev(int nevp)
 {
 
-  if ((nevp<=1)||(nevp>=(n-1))) { // nev must satisfy 1 < nev < n-1.
+  if ((nevp<=1)||(nevp>=(this->n-1))) { // nev must satisfy 1 < nev < n-1.
     throw ArpackError(ArpackError::NEV_OUT_OF_BOUNDS);
   }
   return nevp;
@@ -280,13 +281,13 @@ inline int ARrcNonSymStdEig<FLOAT>::CheckNev(int nevp)
 } // CheckNev.
 
 
-template<class FLOAT>
-bool ARrcNonSymStdEig<FLOAT>::ConjEigVec(int i)
+template<class ARFLOAT>
+bool ARrcNonSymStdEig<ARFLOAT>::ConjEigVec(int i)
 {
 
-  if (EigValI[i] == (FLOAT)0.0) return false;
+  if (this->EigValI[i] == (ARFLOAT)0.0) return false;
   int j = i-1;
-  while ((j >= 0) && (EigValI[j] != (FLOAT)0.0)) j--;
+  while ((j >= 0) && (this->EigValI[j] != (ARFLOAT)0.0)) j--;
   if (((i-j)%2) == 0) {
     return true;
   }
@@ -297,86 +298,86 @@ bool ARrcNonSymStdEig<FLOAT>::ConjEigVec(int i)
 } // ConjEigVec.
 
 
-#ifdef VECTOR_H // Defining functions that use STL vector class.
+#ifdef STL_VECTOR_H // Defining functions that use STL vector class.
 #ifdef ARCOMP_H
 
-template<class FLOAT>
-vector<arcomplex<FLOAT> >* ARrcNonSymStdEig<FLOAT>::
-GenComplex(vector<FLOAT>* RealPart, vector<FLOAT>* ImagPart, bool conj)
+template<class ARFLOAT>
+vector<arcomplex<ARFLOAT> >* ARrcNonSymStdEig<ARFLOAT>::
+GenComplex(vector<ARFLOAT>* RealPart, vector<ARFLOAT>* ImagPart, bool conj)
 {
 
   // Defining variables.
 
-  vector<arcomplex<FLOAT> >* Result;
+  vector<arcomplex<ARFLOAT> >* Result;
   try {
-    Result = new vector<arcomplex<FLOAT> >(ValSize());
+    Result = new vector<arcomplex<ARFLOAT> >(ValSize());
   }
   catch (ArpackError) { return NULL; }
-  FLOAT* rp  = RealPart->begin();
-  FLOAT* ip  = ImagPart->begin();
-  FLOAT* end = RealPart->end();
-  arcomplex<FLOAT>* s = Result->begin();
+  ARFLOAT* rp  = RealPart->begin();
+  ARFLOAT* ip  = ImagPart->begin();
+  ARFLOAT* end = RealPart->end();
+  arcomplex<ARFLOAT>* s = Result->begin();
 
   // Creating a complex vector.
 
   if (!conj) {
-    while (rp != end) *s++ = arcomplex<FLOAT>(*rp++, *ip++);
+    while (rp != end) *s++ = arcomplex<ARFLOAT>(*rp++, *ip++);
   }
   else {
-    while (rp != end) *s++ = arcomplex<FLOAT>(*rp++, -(*ip++));
+    while (rp != end) *s++ = arcomplex<ARFLOAT>(*rp++, -(*ip++));
   }
 
   return Result;
 
-} // GenComplex (vector<FLOAT> version).
+} // GenComplex (vector<ARFLOAT> version).
 
 
-template<class FLOAT>
-vector<arcomplex<FLOAT> >* ARrcNonSymStdEig<FLOAT>::
-GenComplex(int dim, FLOAT* RealPart, FLOAT* ImagPart, bool conj)
+template<class ARFLOAT>
+vector<arcomplex<ARFLOAT> >* ARrcNonSymStdEig<ARFLOAT>::
+GenComplex(int dim, ARFLOAT* RealPart, ARFLOAT* ImagPart, bool conj)
 {
 
   // Defining variables.
 
-  vector<arcomplex<FLOAT> >* Result;
+  vector<arcomplex<ARFLOAT> >* Result;
   try {
-    Result = new vector<arcomplex<FLOAT> >(dim);
+    Result = new vector<arcomplex<ARFLOAT> >(dim);
   }
   catch (ArpackError) { return NULL; }
-  FLOAT* rp  = RealPart; 
-  FLOAT* ip  = ImagPart; 
-  FLOAT* end = &RealPart[dim];
-  arcomplex<FLOAT>* s = Result->begin();
+  ARFLOAT* rp  = RealPart; 
+  ARFLOAT* ip  = ImagPart; 
+  ARFLOAT* end = &RealPart[dim];
+  arcomplex<ARFLOAT>* s = Result->begin();
 
   // Creating a complex vector.
 
   if (!conj) {
-    while (rp != end) *s++ = arcomplex<FLOAT>(*rp++, *ip++);
+    while (rp != end) *s++ = arcomplex<ARFLOAT>(*rp++, *ip++);
   }
   else {
-    while (rp != end) *s++ = arcomplex<FLOAT>(*rp++, -(*ip++));
+    while (rp != end) *s++ = arcomplex<ARFLOAT>(*rp++, -(*ip++));
   }
 
   return Result;
 
-} // GenComplex (FLOAT* version).
+} // GenComplex (ARFLOAT* version).
 
 
-template<class FLOAT>
-vector<arcomplex<FLOAT> >* ARrcNonSymStdEig<FLOAT>::
-GenComplex(int dim, FLOAT* RealPart)
+template<class ARFLOAT>
+vector<arcomplex<ARFLOAT> >* ARrcNonSymStdEig<ARFLOAT>::
+GenComplex(int dim, ARFLOAT* RealPart)
 {
 
   // Defining variables.
 
-  vector<arcomplex<FLOAT> >* Result;
+  vector<arcomplex<ARFLOAT> >* Result;
   try {
-    Result = new vector<arcomplex<FLOAT> >(dim);
+    Result = new vector<arcomplex<ARFLOAT> >(dim);
   }
   catch (ArpackError) { return NULL; }
-  FLOAT* rp  = RealPart; 
-  FLOAT* end = &RealPart[dim];
-  arcomplex<FLOAT>* s = Result->begin();
+  ARFLOAT* rp  = RealPart; 
+  ARFLOAT* end = &RealPart[dim];
+  arcomplex<ARFLOAT>* s = Result->begin();
 
   // Copying a real vector into a complex vector.
 
@@ -387,187 +388,187 @@ GenComplex(int dim, FLOAT* RealPart)
 } // GenComplex.
 
 #endif // ARCOMP_H.
-#endif // VECTOR_H.
+#endif // STL_VECTOR_H.
 
 
-template<class FLOAT>
-FLOAT* ARrcNonSymStdEig<FLOAT>::GetVectorImag()
+template<class ARFLOAT>
+ARFLOAT* ARrcNonSymStdEig<ARFLOAT>::GetVectorImag()
 {
 
-  if (ido != 3) {
+  if (this->ido != 3) {
     throw ArpackError(ArpackError::CANNOT_GET_VECTOR, "GetVectorImag");
   }
-  return &workl[ipntr[6]];
+  return &this->workl[this->ipntr[6]];
 
 } // GetVectorImag.
 
 
-template<class FLOAT>
-int ARrcNonSymStdEig<FLOAT>::
-Eigenvalues(FLOAT* &EigValRp, FLOAT* &EigValIp, bool ivec, bool ischur)
+template<class ARFLOAT>
+int ARrcNonSymStdEig<ARFLOAT>::
+Eigenvalues(ARFLOAT* &EigValRp, ARFLOAT* &EigValIp, bool ivec, bool ischur)
 {
 
-  if (ValuesOK) {                                 // Eigenvalues are available.
+  if (this->ValuesOK) {                                 // Eigenvalues are available.
     if ((EigValRp == NULL)&&(EigValIp == NULL)) { // Moving eigenvalues.
-      EigValRp = EigValR;
-      EigValIp = EigValI;
-      EigValR  = NULL;
-      EigValI  = NULL;
-      newVal   = false;
-      ValuesOK = false;
+      EigValRp = this->EigValR;
+      EigValIp = this->EigValI;
+      this->EigValR  = NULL;
+      this->EigValI  = NULL;
+      this->newVal   = false;
+      this->ValuesOK = false;
     }
     else {                                        // Copying eigenvalues.
       try {
-        if (EigValRp == NULL) EigValRp = new FLOAT[ValSize()];
-        if (EigValIp == NULL) EigValIp = new FLOAT[ValSize()];
+        if (EigValRp == NULL) EigValRp = new ARFLOAT[ValSize()];
+        if (EigValIp == NULL) EigValIp = new ARFLOAT[ValSize()];
       }
       catch (ArpackError) { return 0; }
-      copy(nconv,EigValR,1,EigValRp,1);
-      copy(nconv,EigValI,1,EigValIp,1);
+      copy(this->nconv,this->EigValR,1,EigValRp,1);
+      copy(this->nconv,this->EigValI,1,EigValIp,1);
     }
   }
   else {
-    if (newVal) {
-      delete[] EigValR;
-      delete[] EigValI;
-      newVal = false;
+    if (this->newVal) {
+      delete[] this->EigValR;
+      delete[] this->EigValI;
+      this->newVal = false;
     }
     try {
-      if (EigValRp == NULL) EigValRp = new FLOAT[ValSize()];
-      if (EigValIp == NULL) EigValIp = new FLOAT[ValSize()];
+      if (EigValRp == NULL) EigValRp = new ARFLOAT[ValSize()];
+      if (EigValIp == NULL) EigValIp = new ARFLOAT[ValSize()];
     }
     catch (ArpackError) { return 0; }
-    EigValR = EigValRp;
-    EigValI = EigValIp;
+    this->EigValR = EigValRp;
+    this->EigValI = EigValIp;
     if (ivec) {                              // Finding eigenvalues and vectors.
-      nconv = FindEigenvectors(ischur);
+      this->nconv = this->FindEigenvectors(ischur);
     }
     else {                                   // Finding eigenvalues only.
-      nconv = FindEigenvalues();
+      this->nconv = this->FindEigenvalues();
     }
-    EigValR = NULL;
-    EigValI = NULL;
+    this->EigValR = NULL;
+    this->EigValI = NULL;
   }
-  return nconv;
+  return this->nconv;
 
 } // Eigenvalues(EigValRp, EigValIp, ivec, ischur).
 
 
-template<class FLOAT>
-int ARrcNonSymStdEig<FLOAT>::
-EigenValVectors(FLOAT* &EigVecp, FLOAT* &EigValRp,
-                FLOAT* &EigValIp, bool ischur)
+template<class ARFLOAT>
+int ARrcNonSymStdEig<ARFLOAT>::
+EigenValVectors(ARFLOAT* &EigVecp, ARFLOAT* &EigValRp,
+                ARFLOAT* &EigValIp, bool ischur)
 {
 
-  if (ValuesOK) {               // Eigenvalues are already available .
-    nconv = Eigenvalues(EigValRp, EigValIp, false);
-    nconv = Eigenvectors(EigVecp, ischur);
+  if (this->ValuesOK) {               // Eigenvalues are already available .
+    this->nconv = Eigenvalues(EigValRp, EigValIp, false);
+    this->nconv = Eigenvectors(EigVecp, ischur);
   }
   else {                        // Eigenvalues ans vectors are not available.
-    if (newVec) {
-      delete[] EigVec;
-      newVec = false;
+    if (this->newVec) {
+      delete[] this->EigVec;
+      this->newVec = false;
     }
-    if (newVal) {
-      delete[] EigValR;
-      delete[] EigValI;
-      newVal = false;
+    if (this->newVal) {
+      delete[] this->EigValR;
+      delete[] this->EigValI;
+      this->newVal = false;
     }
     try {
-      if (EigVecp  == NULL) EigVecp  = new FLOAT[ValSize()*n];
-      if (EigValRp == NULL) EigValRp = new FLOAT[ValSize()];
-      if (EigValIp == NULL) EigValIp = new FLOAT[ValSize()];
+      if (EigVecp  == NULL) EigVecp  = new ARFLOAT[ValSize()*this->n];
+      if (EigValRp == NULL) EigValRp = new ARFLOAT[ValSize()];
+      if (EigValIp == NULL) EigValIp = new ARFLOAT[ValSize()];
     }
     catch (ArpackError) { return 0; }
-    EigVec  = EigVecp;
-    EigValR = EigValRp;
-    EigValI = EigValIp;
-    nconv   = FindEigenvectors(ischur);
-    EigVec  = NULL;
-    EigValR = NULL;
-    EigValI = NULL;
+    this->EigVec  = EigVecp;
+    this->EigValR = EigValRp;
+    this->EigValI = EigValIp;
+    this->nconv   = this->FindEigenvectors(ischur);
+    this->EigVec  = NULL;
+    this->EigValR = NULL;
+    this->EigValI = NULL;
   }
-  return nconv;
+  return this->nconv;
 
 } // EigenValVectors(EigVecp, EigValRp, EigValIp, ischur).
 
 
 #ifdef ARCOMP_H
-template<class FLOAT>
-inline arcomplex<FLOAT> ARrcNonSymStdEig<FLOAT>::Eigenvalue(int i)
+template<class ARFLOAT>
+inline arcomplex<ARFLOAT> ARrcNonSymStdEig<ARFLOAT>::Eigenvalue(int i)
 {
 
   // Returning i-eth eigenvalue.
 
-  if (!ValuesOK) {
+  if (!this->ValuesOK) {
     throw ArpackError(ArpackError::VALUES_NOT_OK, "Eigenvalue(i)");
   }
-  else if ((i>=nconv)||(i<0)) {
+  else if ((i>=this->nconv)||(i<0)) {
     throw ArpackError(ArpackError::RANGE_ERROR, "Eigenvalue(i)");
   }
-  return arcomplex<FLOAT>(EigValR[i],EigValI[i]);
+  return arcomplex<ARFLOAT>(this->EigValR[i],this->EigValI[i]);
 
 } // Eigenvalue(i).
 #endif // ARCOMP_H
 
 
-template<class FLOAT>
-inline FLOAT ARrcNonSymStdEig<FLOAT>::EigenvalueReal(int i)
+template<class ARFLOAT>
+inline ARFLOAT ARrcNonSymStdEig<ARFLOAT>::EigenvalueReal(int i)
 {
 
   // Returning the real part of i-eth eigenvalue.
 
-  if (!ValuesOK) {
+  if (!this->ValuesOK) {
     throw ArpackError(ArpackError::VALUES_NOT_OK, "EigenvalueReal(i)");
   }
-  else if ((i>=nconv)||(i<0)) {
+  else if ((i>=this->nconv)||(i<0)) {
     throw ArpackError(ArpackError::RANGE_ERROR, "EigenvalueReal(i)");
   }
-  return EigValR[i];
+  return this->EigValR[i];
 
 } // EigenvalueReal(i).
 
 
-template<class FLOAT>
-inline FLOAT ARrcNonSymStdEig<FLOAT>::EigenvalueImag(int i)
+template<class ARFLOAT>
+inline ARFLOAT ARrcNonSymStdEig<ARFLOAT>::EigenvalueImag(int i)
 {
 
   // Returning the imaginary part of i-eth eigenvalue.
 
-  if (!ValuesOK) {
+  if (!this->ValuesOK) {
     throw ArpackError(ArpackError::VALUES_NOT_OK, "EigenvalueImag(i)");
   }
-  else if ((i>=nconv)||(i<0)) {
+  else if ((i>=this->nconv)||(i<0)) {
     throw ArpackError(ArpackError::RANGE_ERROR, "EigenvalueImag(i)");
   }
-  return EigValI[i];
+  return this->EigValI[i];
 
 } // EigenvalueImag(i).
 
 
 #ifdef ARCOMP_H
-template<class FLOAT>
-inline arcomplex<FLOAT> ARrcNonSymStdEig<FLOAT>::
+template<class ARFLOAT>
+inline arcomplex<ARFLOAT> ARrcNonSymStdEig<ARFLOAT>::
 Eigenvector(int i, int j)
 {
 
   // Returning element j of i-eth eigenvector.
 
-  if ((!VectorsOK)||(!ValuesOK)) {
+  if ((!this->VectorsOK)||(!this->ValuesOK)) {
     throw ArpackError(ArpackError::VECTORS_NOT_OK, "Eigenvector(i,j)");
   }
-  else if ((i>=nconv)||(i<0)||(j>=n)||(j<0)) {
+  else if ((i>=this->nconv)||(i<0)||(j>=this->n)||(j<0)) {
     throw ArpackError(ArpackError::RANGE_ERROR, "Eigenvector(i,j)");
   }
-  if (EigValI[i]==(FLOAT)0.0) {   // Real eigenvalue.
-    return arcomplex<FLOAT>(EigVec[i*n+j],(FLOAT)0.0);
+  if (this->EigValI[i]==(ARFLOAT)0.0) {   // Real eigenvalue.
+    return arcomplex<ARFLOAT>(this->EigVec[i*this->n+j],(ARFLOAT)0.0);
   }
-  else {                          // Complex eigenvalue.
-    if (EigValI[i]>(FLOAT)0.0) {  // with positive imaginary part.
-      return arcomplex<FLOAT>(EigVec[i*n+j], EigVec[(i+1)*n+j]);
+  else {                            // Complex eigenvalue.
+    if (this->EigValI[i]>(ARFLOAT)0.0) {  // with positive imaginary part.
+      return arcomplex<ARFLOAT>(this->EigVec[i*this->n+j], this->EigVec[(i+1)*this->n+j]);
     }
-    else {                        // with negative imaginary part.
-      return arcomplex<FLOAT>(EigVec[(i-1)*n+j], -EigVec[i*n+j]);
+    else {                          // with negative imaginary part.
+      return arcomplex<ARFLOAT>(this->EigVec[(i-1)*this->n+j], -this->EigVec[i*this->n+j]);
     }
   }
 
@@ -575,67 +576,67 @@ Eigenvector(int i, int j)
 #endif // ARCOMP_H
 
 
-template<class FLOAT>
-inline FLOAT ARrcNonSymStdEig<FLOAT>::EigenvectorReal(int i, int j)
+template<class ARFLOAT>
+inline ARFLOAT ARrcNonSymStdEig<ARFLOAT>::EigenvectorReal(int i, int j)
 {
 
   // Returning the real part of element j of i-eth eigenvector.
 
-  if (!VectorsOK) {
+  if (!this->VectorsOK) {
     throw ArpackError(ArpackError::VECTORS_NOT_OK, "EigenvectorReal(i,j)");
   }
-  else if ((i>=nconv)||(i<0)||(j>=n)||(j<0)) {
+  else if ((i>=this->nconv)||(i<0)||(j>=this->n)||(j<0)) {
     throw ArpackError(ArpackError::RANGE_ERROR, "EigenvectorReal(i,j)");
   }
-  return EigVec[i*n+j];
+  return this->EigVec[i*this->n+j];
 
 } // EigenvectorReal(i,j).
 
 
-template<class FLOAT>
-inline FLOAT ARrcNonSymStdEig<FLOAT>::EigenvectorImag(int i, int j)
+template<class ARFLOAT>
+inline ARFLOAT ARrcNonSymStdEig<ARFLOAT>::EigenvectorImag(int i, int j)
 {
 
   // Returning the imaginary part of element j of i-eth eigenvector.
 
-  if ((!VectorsOK)||(!ValuesOK)) {
+  if ((!this->VectorsOK)||(!this->ValuesOK)) {
     throw ArpackError(ArpackError::VECTORS_NOT_OK, "EigenvectorImag(i,j)");
   }
-  else if ((i>=nconv)||(i<0)||(j>=n)||(j<0)) {
+  else if ((i>=this->nconv)||(i<0)||(j>=this->n)||(j<0)) {
     throw ArpackError(ArpackError::RANGE_ERROR, "EigenvectorImag(i,j)");
   }
-  if (EigValI[i]==(FLOAT)0.0) {   // Real eigenvalue.
-    return (FLOAT)0.0;
+  if (this->EigValI[i]==(ARFLOAT)0.0) {   // Real eigenvalue.
+    return (ARFLOAT)0.0;
   }
-  else {                          // Complex eigenvalue.
-    if (EigValI[i]>(FLOAT)0.0) {  // with positive imaginary part.
-      return EigVec[(i+1)*n+j];
+  else {                            // Complex eigenvalue.
+    if (this->EigValI[i]>(ARFLOAT)0.0) {  // with positive imaginary part.
+      return this->EigVec[(i+1)*this->n+j];
     }
-    else {                        // with negative imaginary part.
-      return -EigVec[i*n+j];
+    else {                          // with negative imaginary part.
+      return -this->EigVec[i*this->n+j];
     }
   }
 
 } // EigenvectorImag(i,j).
 
 
-template<class FLOAT>
-inline FLOAT* ARrcNonSymStdEig<FLOAT>::RawEigenvaluesImag()
+template<class ARFLOAT>
+inline ARFLOAT* ARrcNonSymStdEig<ARFLOAT>::RawEigenvaluesImag()
 {
 
-  if (!ValuesOK) {
+  if (!this->ValuesOK) {
     throw ArpackError(ArpackError::VALUES_NOT_OK, "RawEigenvaluesImag");
   }
-  return EigValI;
+  return this->EigValI;
 
 } // RawEigenvaluesImag.
 
 
-#ifdef VECTOR_H // Defining some functions that use STL vector class.
+#ifdef STL_VECTOR_H // Defining some functions that use STL vector class.
 
 #ifdef ARCOMP_H
-template<class FLOAT>
-inline vector<arcomplex<FLOAT> >* ARrcNonSymStdEig<FLOAT>::
+template<class ARFLOAT>
+inline vector<arcomplex<ARFLOAT> >* ARrcNonSymStdEig<ARFLOAT>::
 StlEigenvalues(bool ivec, bool ischur)
 {
 
@@ -643,14 +644,14 @@ StlEigenvalues(bool ivec, bool ischur)
 
   // Defining temporary variables.
 
-  vector<FLOAT>* StlEigValR;
-  vector<FLOAT>* StlEigValI;
-  FLOAT*         ValRPtr;
-  FLOAT*         ValIPtr;
+  vector<ARFLOAT>* StlEigValR;
+  vector<ARFLOAT>* StlEigValI;
+  ARFLOAT*         ValRPtr;
+  ARFLOAT*         ValIPtr;
 
   try {
-    StlEigValR = new vector<FLOAT>(ValSize());
-    StlEigValI = new vector<FLOAT>(ValSize());
+    StlEigValR = new vector<ARFLOAT>(ValSize());
+    StlEigValI = new vector<ARFLOAT>(ValSize());
   }
   catch (ArpackError) { return NULL; }
 
@@ -659,7 +660,7 @@ StlEigenvalues(bool ivec, bool ischur)
   ValRPtr = StlEigValR->begin();
   ValIPtr = StlEigValI->begin();
   nconv = Eigenvalues(ValRPtr, ValIPtr, ivec, ischur);
-  vector<arcomplex<FLOAT> >* Val = GenComplex(StlEigValR, StlEigValI);
+  vector<arcomplex<ARFLOAT> >* Val = GenComplex(StlEigValR, StlEigValI);
 
   // Deleting temporary variables.
 
@@ -672,19 +673,19 @@ StlEigenvalues(bool ivec, bool ischur)
 #endif // ARCOMP_H.
 
 
-template<class FLOAT>
-inline vector<FLOAT>* ARrcNonSymStdEig<FLOAT>::StlEigenvaluesReal()
+template<class ARFLOAT>
+inline vector<ARFLOAT>* ARrcNonSymStdEig<ARFLOAT>::StlEigenvaluesReal()
 {
 
   // Returning the real part of the eigenvalues in a STL vector.
 
-  vector<FLOAT>* StlEigValR;
+  vector<ARFLOAT>* StlEigValR;
   
   if (!ValuesOK) {
     throw ArpackError(ArpackError::VALUES_NOT_OK, "StlEigenvaluesReal");
   }
   try {
-    StlEigValR = new vector<FLOAT>(EigValR, &EigValR[ValSize()]);
+    StlEigValR = new vector<ARFLOAT>(EigValR, &EigValR[ValSize()]);
   }
   catch (ArpackError) { return NULL; }
   return StlEigValR;
@@ -692,19 +693,19 @@ inline vector<FLOAT>* ARrcNonSymStdEig<FLOAT>::StlEigenvaluesReal()
 } // StlEigenvaluesReal.
 
 
-template<class FLOAT>
-inline vector<FLOAT>* ARrcNonSymStdEig<FLOAT>::StlEigenvaluesImag()
+template<class ARFLOAT>
+inline vector<ARFLOAT>* ARrcNonSymStdEig<ARFLOAT>::StlEigenvaluesImag()
 {
 
   // Returning the imaginary part of the eigenvalues in a STL vector.
 
-  vector<FLOAT>* StlEigValI;
+  vector<ARFLOAT>* StlEigValI;
 
   if (!ValuesOK) {
     throw ArpackError(ArpackError::VALUES_NOT_OK, "StlEigenvaluesImag");
   }
   try {
-    StlEigValI = new vector<FLOAT>(EigValI, &EigValI[ValSize()]);
+    StlEigValI = new vector<ARFLOAT>(EigValI, &EigValI[ValSize()]);
   }
   catch (ArpackError) { return NULL; }
   return StlEigValI;
@@ -713,8 +714,8 @@ inline vector<FLOAT>* ARrcNonSymStdEig<FLOAT>::StlEigenvaluesImag()
 
 
 #ifdef ARCOMP_H
-template<class FLOAT>
-inline vector<arcomplex<FLOAT> >* ARrcNonSymStdEig<FLOAT>::
+template<class ARFLOAT>
+inline vector<arcomplex<ARFLOAT> >* ARrcNonSymStdEig<ARFLOAT>::
 StlEigenvector(int i)
 {
 
@@ -726,7 +727,7 @@ StlEigenvector(int i)
   else if ((i>=ValSize())||(i<0)) {
     throw ArpackError(ArpackError::RANGE_ERROR, "StlEigenvector(i)");
   }
-  if (EigValI[i] == (FLOAT)0.0) { // Real eigenvector.
+  if (EigValI[i] == (ARFLOAT)0.0) { // Real eigenvector.
     return GenComplex(n, &EigVec[i*n]);
   }
   else if (!ConjEigVec(i)) {      // First eigenvector in a conjugate pair.
@@ -740,13 +741,13 @@ StlEigenvector(int i)
 #endif // ARCOMP_H.
 
 
-template<class FLOAT>
-inline vector<FLOAT>* ARrcNonSymStdEig<FLOAT>::StlEigenvectorReal(int i)
+template<class ARFLOAT>
+inline vector<ARFLOAT>* ARrcNonSymStdEig<ARFLOAT>::StlEigenvectorReal(int i)
 {
 
   // Returning the real part of the i-th eigenvector in a STL vector.
 
-  vector<FLOAT>* Vec;
+  vector<ARFLOAT>* Vec;
 
   if (!VectorsOK) {
     throw ArpackError(ArpackError::VECTORS_NOT_OK, "StlEigenvectorReal(i)");
@@ -756,14 +757,14 @@ inline vector<FLOAT>* ARrcNonSymStdEig<FLOAT>::StlEigenvectorReal(int i)
   }
   if (!ConjEigVec(i)) { // Real eigenvector or first in a conj. pair.
     try {
-      Vec = new vector<FLOAT>(&EigVec[i*n], &EigVec[(i+1)*n]);
+      Vec = new vector<ARFLOAT>(&EigVec[i*n], &EigVec[(i+1)*n]);
     }
     catch (ArpackError) { return NULL; }
     return Vec;
   }
   else {                // Second eigenvector in a conjugate pair.
     try {
-      Vec = new vector<FLOAT>(&EigVec[(i-1)*n], &EigVec[i*n]);
+      Vec = new vector<ARFLOAT>(&EigVec[(i-1)*n], &EigVec[i*n]);
     }
     catch (ArpackError) { return NULL; }
     return Vec;
@@ -772,13 +773,13 @@ inline vector<FLOAT>* ARrcNonSymStdEig<FLOAT>::StlEigenvectorReal(int i)
 } // StlEigenvectorReal(i).
 
 
-template<class FLOAT>
-inline vector<FLOAT>* ARrcNonSymStdEig<FLOAT>::StlEigenvectorImag(int i)
+template<class ARFLOAT>
+inline vector<ARFLOAT>* ARrcNonSymStdEig<ARFLOAT>::StlEigenvectorImag(int i)
 {
 
   // Returning the imaginary part of the i-th eigenvector in a STL vector.
 
-  vector<FLOAT>* Vec;
+  vector<ARFLOAT>* Vec;
 
   if (!VectorsOK) {
     throw ArpackError(ArpackError::VECTORS_NOT_OK, "StlEigenvectorImag(i)");
@@ -786,51 +787,51 @@ inline vector<FLOAT>* ARrcNonSymStdEig<FLOAT>::StlEigenvectorImag(int i)
   else if ((i>=ValSize())||(i<0)) {
     throw ArpackError(ArpackError::RANGE_ERROR, "StlEigenvectorImag(i)");
   }
-  if (EigValI[i] == (FLOAT)0.0) { // Real eigenvector.
+  if (EigValI[i] == (ARFLOAT)0.0) { // Real eigenvector.
     try {
-      Vec = new vector<FLOAT>(ValSize(), (FLOAT)0.0);
+      Vec = new vector<ARFLOAT>(ValSize(), (ARFLOAT)0.0);
     }
     catch (ArpackError) { return NULL; }
     return Vec;
   }
   else if (!ConjEigVec(i)) {      // First eigenvector in a conjugate pair.
     try {
-      Vec = new vector<FLOAT>(&EigVec[(i+1)*n], &EigVec[(i+2)*n]);
+      Vec = new vector<ARFLOAT>(&EigVec[(i+1)*n], &EigVec[(i+2)*n]);
     }
     catch (ArpackError) { return NULL; }
     return Vec;
   }
   else {                          // Second eigenvector in a conjugate pair.
     try {
-      Vec = new vector<FLOAT>(&EigVec[i*n], &EigVec[(i+1)*n]);
+      Vec = new vector<ARFLOAT>(&EigVec[i*n], &EigVec[(i+1)*n]);
     }
     catch (ArpackError) { return NULL; }
-    for (FLOAT* s = Vec->begin(); s != Vec->end(); s++) *s = -(*s);
+    for (ARFLOAT* s = Vec->begin(); s != Vec->end(); s++) *s = -(*s);
     return Vec;
   }
 
 } // StlEigenvectorImag(i).
 
-#endif // VECTOR_H.
+#endif // STL_VECTOR_H.
 
 
-template<class FLOAT>
-inline ARrcNonSymStdEig<FLOAT>::
+template<class ARFLOAT>
+inline ARrcNonSymStdEig<ARFLOAT>::
 ARrcNonSymStdEig(int np, int nevp, char* whichp, int ncvp,
-                 FLOAT tolp, int maxitp, FLOAT* residp, bool ishiftp)
+                 ARFLOAT tolp, int maxitp, ARFLOAT* residp, bool ishiftp)
 
 {
 
-  NoShift();
+  this->NoShift();
   DefineParameters(np, nevp, whichp, ncvp, tolp, maxitp, residp, ishiftp);
 
 } // Long constructor (regular mode).
 
 
-template<class FLOAT>
-inline ARrcNonSymStdEig<FLOAT>::
-ARrcNonSymStdEig(int np, int nevp, FLOAT sigmap, char* whichp, int ncvp,
-                 FLOAT tolp, int maxitp, FLOAT* residp, bool ishiftp)
+template<class ARFLOAT>
+inline ARrcNonSymStdEig<ARFLOAT>::
+ARrcNonSymStdEig(int np, int nevp, ARFLOAT sigmap, char* whichp, int ncvp,
+                 ARFLOAT tolp, int maxitp, ARFLOAT* residp, bool ishiftp)
 
 {
 
@@ -840,13 +841,13 @@ ARrcNonSymStdEig(int np, int nevp, FLOAT sigmap, char* whichp, int ncvp,
 } // Long constructor (shift and invert mode).
 
 
-template<class FLOAT>
-ARrcNonSymStdEig<FLOAT>& ARrcNonSymStdEig<FLOAT>::
-operator=(const ARrcNonSymStdEig<FLOAT>& other)
+template<class ARFLOAT>
+ARrcNonSymStdEig<ARFLOAT>& ARrcNonSymStdEig<ARFLOAT>::
+operator=(const ARrcNonSymStdEig<ARFLOAT>& other)
 {
 
   if (this != &other) { // Stroustrup suggestion.
-    ClearMem();
+    this->ClearMem();
     Copy(other);
   }
   return *this;
