@@ -20,7 +20,7 @@
 #include "arch.h"
 #include "arpackf.h"
 
-extern arpack_debug F77NAME(debug);
+extern "C" arpack_debug F77NAME(debug);
 
 inline void TraceOff()
 
