@@ -1,5 +1,5 @@
 /*
-   ARPACK++ v1.0 8/1/1997
+   ARPACK++ v1.2 2/20/2000
    c++ interface to ARPACK code.
 
    MODULE naupp.h.
@@ -20,10 +20,10 @@
 #include "arch.h"
 #include "arpackf.h"
 
-inline void naupp(int& ido, char bmat, int n, char* which, int nev,
-                  double& tol, double resid[], int ncv, double V[],
-                  int ldv, int iparam[], int ipntr[], double workd[],
-                  double workl[], int lworkl, int& info)
+inline void naupp(ARint& ido, char bmat, ARint n, char* which, ARint nev,
+                  double& tol, double resid[], ARint ncv, double V[],
+                  ARint ldv, ARint iparam[], ARint ipntr[], double workd[],
+                  double workl[], ARint lworkl, ARint& info)
 
 /*
   c++ version of ARPACK routine dnaupd that implements a variant of
@@ -308,10 +308,10 @@ inline void naupp(int& ido, char bmat, int n, char* which, int nev,
 
 } // naupp (double).
 
-inline void naupp(int& ido, char bmat, int n, char* which, int nev,
-                  float& tol, float resid[], int ncv, float V[],
-                  int ldv, int iparam[], int ipntr[], float workd[],
-                  float workl[], int lworkl, int& info)
+inline void naupp(ARint& ido, char bmat, ARint n, char* which, ARint nev,
+                  float& tol, float resid[], ARint ncv, float V[],
+                  ARint ldv, ARint iparam[], ARint ipntr[], float workd[],
+                  float workl[], ARint lworkl, ARint& info)
 
 /*
   c++ version of ARPACK routine snaupd. The only difference between
